@@ -23,12 +23,9 @@
 #include "FileType.h"
 #include "amarokshared_export.h"
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wnon-virtual-dtor"
 #include <fileref.h>
 #include <tag.h>
 #include <id3v1tag.h>
-#pragma GCC diagnostic pop
 
 namespace Meta
 {
