@@ -25,8 +25,6 @@
 #include <KSelectAction>
 #include <KToggleAction>
 
-#include <phonon/Global>
-
 class KActionCollection;
 class KHelpMenu;
 
@@ -96,11 +94,7 @@ namespace Amarok
             QString currentIcon() const;
 
         protected Q_SLOTS:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            void actionTriggered( QAction *a ) override;
-#else
             void slotActionTriggered( QAction *a ) override;
-#endif
 
         private:
             void ( *m_function ) ( int );
