@@ -833,7 +833,7 @@ EngineController::slotAboutToFinish()
 
         //stop this track, now, as the source track might go on and on, and
         //there might not be any more tracks in the playlist...
-        stop( true );
+        stop( true, true );
         The::playlistActions()->requestNextTrack();
     }
     else if( m_pipeline->isPlaybackQueueEmpty() )
@@ -1063,8 +1063,10 @@ EngineController::slotMetaDataChanged()
 {
     QVariantMap meta;
     meta.insert( Meta::Field::URL, m_pipeline->currentSource() );
-    for (const auto &key : m_pipeline->metaData().keys()) {
-        const QStringList values = m_pipeline->metaData().values( key );
+    // metadata might be changed by pipeline during for, so take a copy
+    const QMultiMap<QString, QString> metadata = m_pipeline->metaData();
+    for (const auto &key : metadata.keys()) {
+        const QStringList values = metadata.values( key );
         if( values.isEmpty() )
             continue;
         else if( key == QLatin1String("ARTIST") )
@@ -1150,8 +1152,11 @@ void EngineController::slotVolumeChanged( qreal newVolume )
 
 void EngineController::slotMutedChanged( bool mute )
 {
-    AmarokConfig::setMuteState( mute );
-    Q_EMIT muteStateChanged( mute );
+    if( mute != AmarokConfig::muteState() )
+    {
+        AmarokConfig::setMuteState( mute );
+        Q_EMIT muteStateChanged( mute );
+    }
 }
 
 void
