@@ -4,6 +4,7 @@
  * Copyright (c) 2004-2013 Mark Kretschmann <kretschmann@kde.org>                       *
  * Copyright (c) 2008 Jason A. Donenfeld <Jason@zx2c4.com>                              *
  * Copyright (c) 2009 Artur Szymiec <artur.szymiec@gmail.com>                           *
+ * Copyright (C) 2025 Tuomas Nurmi <tuomas@norsumanageri.org>                           *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -28,26 +29,18 @@
 #include "core/meta/Meta.h"
 
 #include <QRecursiveMutex>
-#include <QObject>
 #include <QPointer>
 #include <QSemaphore>
 #include <QStringList>
 #include <QUrl>
 
-#include <phonon/Path>
-#include <phonon/MediaController>
-#include <phonon/MediaObject>
-#include <phonon/Effect>
-#include <phonon/EffectParameter>
-#include <phonon/audiodataoutput.h>
-
+class EngineGstPipeline;
 class Fadeouter;
 namespace Capabilities { class MultiPlayableCapability; class MultiSourceCapability; }
-namespace Phonon { class AudioOutput; class MediaSource; class VolumeFaderEffect; }
 class QTimer;
 
 /**
- * A thin wrapper around Phonon that implements Amarok-specific functionality like
+ * A thin wrapper around GStreamer that implements Amarok-specific functionality like
  * replay gain, fade-out on stop and various track capabilities that affect
  * playback.
  */
@@ -138,19 +131,6 @@ public:
      */
     bool isStopped() const;
 
-    /**
-     * Streams sometimes have to be treated specially.
-     * For example, it is typically not possible to rewind a stream (at least,
-     * not without returning to the start of it).
-     * However for rewinding we have isSeekable().
-     * Also for streams usually the meta data received by currentTrack() is only
-     * for the whole stream while the meta data received by currentMetaDataChanged
-     * will be more current (or contain advertisement)
-     *
-     * @return @c true if the current track is a stream, @c false otherwise
-     */
-    bool isStream();
-
     /**
      * @return @c true if the current track is seekable, @c false otherwise
      */
@@ -167,6 +147,7 @@ public:
      */
     QString prettyNowPlaying( bool progress = false ) const;
 
+
 public Q_SLOTS:
     /**
      * Plays the current track, if there is one
@@ -299,17 +280,6 @@ public Q_SLOTS:
      */
     bool supportsFadeout() const;
 
-    /**
-     * Return true if current Phonon back-end supports our implementation of
-     * Replay Gain adjustment.
-     */
-    bool supportsGainAdjustments() const;
-
-    /**
-     * Return true if the current Phonon backend supports visualizations.
-     */
-    bool supportsAudioDataOutput() const;
-
 Q_SIGNALS:
     /**
      * Emitted when the playback stops while playing a track.
@@ -445,7 +415,7 @@ Q_SIGNALS:
     *   Is emitted when new audio Data is ready
     *   @param audioData The audio data that is available
     */
-    void audioDataReady( const QMap<Phonon::AudioDataOutput::Channel, QVector<qint16> > &audioData );
+    void audioDataReady( const QMap<int, QVector<qint16> > &audioData );
 
     /**
      * A trick to call slotFillInSupportedMimeTypes() in a main thread, not to be used
@@ -455,16 +425,16 @@ Q_SIGNALS:
 
 private Q_SLOTS:
     /**
-     * Sets up the Phonon system
+     * Sets up the audio backend
      */
-    void initializePhonon();
+    void initializeBackend();
     /** This slot is connected to the phonon finished signal.
         It is emitted when the queue is empty and the current media come to an end.
     */
     void slotFinished();
     void slotAboutToFinish();
-    void slotNewTrackPlaying( const Phonon::MediaSource &source);
-    void slotStateChanged( Phonon::State newState, Phonon::State oldState);
+    void slotNewTrackPlaying( const QUrl &source );
+    void slotStateChanged( int oldState,  int newState );
     void slotPlayableUrlFetched( const QUrl &url );
     void slotTick( qint64 );
     void slotTrackLengthChanged( qint64 );
@@ -546,16 +516,12 @@ private:
     Q_DISABLE_COPY( EngineController )
 
     EqualizerController                     *m_equalizerController;
-    QPointer<Phonon::MediaObject>       m_media;
-    QPointer<Phonon::VolumeFaderEffect> m_preamp;
-    QPointer<Phonon::AudioOutput>       m_audio;
-    QPointer<Phonon::AudioDataOutput>   m_audioDataOutput;
-    QPointer<Phonon::MediaController>   m_controller;
-    Phonon::Path                            m_path;
-    Phonon::Path                            m_dataPath;
+
+    EngineGstPipeline *m_pipeline;
+    bool m_seekablePipeline;
 
     QPointer<Fadeouter> m_fadeouter;
-    QPointer<Phonon::VolumeFaderEffect> m_fader;
+    bool m_fader;
 
     Meta::TrackPtr  m_currentTrack;
     Meta::AlbumPtr  m_currentAlbum;
@@ -586,8 +552,6 @@ private:
 
     QRecursiveMutex m_mutex;
 
-    // FIXME: this variable should be updated when
-    // Phonon::BackendCapabilities::notifier()'s capabilitiesChanged signal is emitted
     QStringList m_supportedMimeTypes;
     QSemaphore m_supportedMimeTypesSemaphore;
 };
