@@ -29,11 +29,12 @@
 #include <gst/audio/audio-format.h>
 
 EngineGstPipeline::EngineGstPipeline()
-    : m_replayGainElement(nullptr)
+    : m_currentSinkElement(nullptr)
+    , m_replayGainElement(nullptr)
     , m_equalizerElement(nullptr)
-    , m_analyzerDataSize(512)
     , m_channels(1)
     , m_handlingAboutToFinish(false)
+    , m_currentState(GST_STATE_NULL)
     , m_tickTimer(new QTimer(this))
     , m_waitingForNextSource(true)
     , m_waitingForPreviousSource(false)
@@ -48,11 +49,9 @@ EngineGstPipeline::EngineGstPipeline()
 
     DEBUG_BLOCK
     qRegisterMetaType<GstState>("GstState");
-    m_pipeline = GST_PIPELINE(gst_element_factory_make("playbin", nullptr));
+    m_pipeline = GST_PIPELINE(gst_element_factory_make("playbin3", nullptr));
     gst_object_ref_sink (m_pipeline);
-    g_signal_connect(m_pipeline, "audio-tags-changed", G_CALLBACK(cb_audioTagsChanged), this);
-    g_signal_connect(m_pipeline, "notify::source", G_CALLBACK(cb_setupSource), this);
-    g_signal_connect(m_pipeline, "notify::volume", G_CALLBACK (cb_volumeChanged), this);
+    g_signal_connect(m_pipeline, "source-setup", G_CALLBACK(cb_setupSource), this);
     g_signal_connect(m_pipeline, "about-to-finish", G_CALLBACK(cb_aboutToFinish), this);
 
     GstBus *bus = gst_pipeline_get_bus(m_pipeline);
@@ -68,7 +67,6 @@ EngineGstPipeline::EngineGstPipeline()
     gst_object_unref(bus);
 
     g_object_set(m_pipeline, "video-sink", gst_element_factory_make( "fakesink", "discard_video" ), nullptr); // Discard any video
-    m_gstVolume = gst_bin_get_by_interface( GST_BIN(m_pipeline), GST_TYPE_STREAM_VOLUME);
 
     m_replayGainElement = gst_element_factory_make("volume", "replaygain");
     m_equalizerElement = gst_element_factory_make("equalizer-10bands", "equalizer");
@@ -87,6 +85,8 @@ EngineGstPipeline::EngineGstPipeline()
 
         GstElement *queue = gst_element_factory_make("queue", "output-queue");
         GstElement *audioSink = gst_element_factory_make("autoaudiosink", "audio-output");
+        g_signal_connect(audioSink, "child-added", G_CALLBACK(cb_sinkElementAdded), this);
+        g_signal_connect(audioSink, "child-removed", G_CALLBACK(cb_sinkElementRemoved), this);
 
         gst_bin_add_many(GST_BIN(bin), queue, audioSink, nullptr);
         if( !gst_element_link(queue, audioSink) )
@@ -169,10 +169,12 @@ EngineGstPipeline::EngineGstPipeline()
         g_object_set( GST_BIN(m_pipeline), "audio-sink", bin, nullptr);
     }
     else
+    {
         debug() << "failed to create custom playback bin";
+        g_signal_connect( m_pipeline, "notify::volume", G_CALLBACK (cb_volumeChanged), this);
+        g_signal_connect( m_pipeline, "notify::mute", G_CALLBACK (cb_muteChanged), this);
+    }
 
-    if(m_gstVolume)
-        gst_object_ref(m_gstVolume);
     if(m_replayGainElement)
         gst_object_ref(m_replayGainElement);
     if(m_equalizerElement)
@@ -185,8 +187,6 @@ EngineGstPipeline::EngineGstPipeline()
 
 EngineGstPipeline::~EngineGstPipeline()
 {
-    if(m_gstVolume)
-        gst_object_unref(m_gstVolume);
     if(m_replayGainElement)
         gst_object_unref(m_replayGainElement);
     if(m_equalizerElement)
@@ -212,15 +212,23 @@ EngineGstPipeline::metaData() const
 bool
 EngineGstPipeline::isMuted()
 {
-    if( m_gstVolume )
-        return gst_stream_volume_get_mute(GST_STREAM_VOLUME(m_gstVolume));
-    return false;
+    gboolean mute;
+    if( !m_currentSinkElement )
+        g_object_get(GST_BIN(m_pipeline), "mute", &mute, nullptr);
+    else
+        g_object_get(G_OBJECT(m_currentSinkElement), "mute", &mute, nullptr);
+    return mute;
 }
 
 qreal
 EngineGstPipeline::volume()
 {
-    return m_gstVolume ? gst_stream_volume_get_volume(GST_STREAM_VOLUME(m_gstVolume), GST_STREAM_VOLUME_FORMAT_CUBIC) : 1;
+    gdouble vol;
+    if( !m_currentSinkElement )
+        g_object_get(GST_BIN(m_pipeline), "volume", &vol, nullptr);
+    else
+        g_object_get(G_OBJECT(m_currentSinkElement), "volume", &vol, nullptr);
+    return gst_stream_volume_convert_volume(GST_STREAM_VOLUME_FORMAT_LINEAR, GST_STREAM_VOLUME_FORMAT_CUBIC, vol);
 }
 
 GstElement*
@@ -232,15 +240,19 @@ EngineGstPipeline::eqElement()
 void
 EngineGstPipeline::setMuted(bool status)
 {
-    if(m_gstVolume)
-        gst_stream_volume_set_mute(GST_STREAM_VOLUME(m_gstVolume), status);
+    if( m_currentSinkElement )
+        g_object_set( G_OBJECT(m_currentSinkElement), "mute", status, nullptr);
+    else
+        g_object_set( GST_BIN(m_pipeline), "mute", status, nullptr);
 }
 
 void
 EngineGstPipeline::setVolume(qreal newVolume)
 {
-    if( m_gstVolume )
-        gst_stream_volume_set_volume(GST_STREAM_VOLUME(m_gstVolume), GST_STREAM_VOLUME_FORMAT_CUBIC, newVolume);
+    if( m_currentSinkElement )
+        g_object_set( G_OBJECT(m_currentSinkElement), "volume", gst_stream_volume_convert_volume(GST_STREAM_VOLUME_FORMAT_CUBIC, GST_STREAM_VOLUME_FORMAT_LINEAR, newVolume), nullptr);
+    else
+        g_object_set( GST_BIN(m_pipeline), "volume", gst_stream_volume_convert_volume(GST_STREAM_VOLUME_FORMAT_CUBIC, GST_STREAM_VOLUME_FORMAT_LINEAR, newVolume), nullptr);
 }
 
 static const qreal log10over20 = 0.1151292546497022842; // ln(10) / 20
@@ -411,6 +423,32 @@ EngineGstPipeline::state() const
     return state;
 }
 
+void
+EngineGstPipeline::cb_sinkElementAdded(GstChildProxy *self, GObject *object, gchar *name, gpointer data)
+{
+    Q_UNUSED(self)
+    Q_UNUSED(name)
+    if( !g_object_class_find_property(G_OBJECT_GET_CLASS(object), "volume") )
+        return;
+    EngineGstPipeline *that = static_cast<EngineGstPipeline*>(data);
+    that->m_currentSinkElement = GST_ELEMENT(object);
+    g_object_set(G_OBJECT(that->m_currentSinkElement), "mute", AmarokConfig::muteState(), NULL);
+    g_object_set(G_OBJECT(that->m_currentSinkElement), "volume", gst_stream_volume_convert_volume(GST_STREAM_VOLUME_FORMAT_CUBIC, GST_STREAM_VOLUME_FORMAT_LINEAR, AmarokConfig::masterVolume()/100.0), NULL);
+    g_signal_connect(that->m_currentSinkElement, "notify::volume", G_CALLBACK (cb_volumeChanged), that);
+    g_signal_connect(that->m_currentSinkElement, "notify::mute", G_CALLBACK (cb_muteChanged), that);
+}
+
+
+void
+EngineGstPipeline::cb_sinkElementRemoved(GstChildProxy *self, GObject *object, gchar *name, gpointer data)
+{
+    Q_UNUSED(self)
+    Q_UNUSED(name)
+    EngineGstPipeline *that = static_cast<EngineGstPipeline*>(data);
+    if(GST_ELEMENT(object) == that->m_currentSinkElement)
+        that->m_currentSinkElement = nullptr;
+}
+
 gboolean
 EngineGstPipeline::cb_eos(GstBus *bus, GstMessage *gstMessage, gpointer data)
 {
@@ -470,26 +508,22 @@ EngineGstPipeline::cb_duration(GstBus *bus, GstMessage *gstMessage, gpointer dat
 }
 
 void
-EngineGstPipeline::cb_setupSource(GstElement *playbin, GParamSpec *param, gpointer data)
+EngineGstPipeline::cb_setupSource(GstElement *playbin, GstElement *source, gpointer data)
 {
     Q_UNUSED(playbin);
-    Q_UNUSED(param);
     DEBUG_BLOCK;
 
-    GstElement *src;
     EngineGstPipeline *that = static_cast<EngineGstPipeline*>(data);
     Q_ASSERT(that->m_pipeline);
-    Q_ASSERT(G_IS_OBJECT(that->m_pipeline));
-    g_object_get(that->m_pipeline, "source", &src, nullptr);
 
     if ( ( that->currentSource().scheme().startsWith(QLatin1String("http") ) ||
            that->currentSource().scheme().startsWith(QLatin1String("rt") ) ) // rtp, rtsp
         // Check whether this property exists.
         // Setting it on a source other than souphttpsrc (which supports it) may break playback.
-        && g_object_class_find_property(G_OBJECT_GET_CLASS(src), "user-agent") )
+        && g_object_class_find_property(G_OBJECT_GET_CLASS(source), "user-agent") )
     {
         QString userAgent = ( QStringLiteral( "Amarok/" ) + QStringLiteral(AMAROK_VERSION) );
-        g_object_set(src, "user-agent", userAgent.toUtf8().constData(), nullptr);
+        g_object_set(source, "user-agent", userAgent.toUtf8().constData(), nullptr);
     }
 }
 
@@ -505,11 +539,14 @@ EngineGstPipeline::cb_volumeChanged(GstElement *playbin, GParamSpec *spec, gpoin
 }
 
 void
-EngineGstPipeline::cb_audioTagsChanged(GstElement *playbin, gint stream, gpointer data)
+EngineGstPipeline::cb_muteChanged(GstElement *playbin, GParamSpec *spec, gpointer data)
 {
     Q_UNUSED(playbin)
+
     EngineGstPipeline *that = static_cast<EngineGstPipeline *>(data);
-    Q_EMIT that->audioTagChanged(stream);
+    Q_EMIT that->mutedChanged( that->isMuted() );
+    Q_UNUSED(spec)
+    Q_UNUSED(data)
 }
 
 gboolean
@@ -790,7 +827,13 @@ EngineGstPipeline::cb_state(GstBus *bus, GstMessage *gstMessage, gpointer data)
     }
 
     Q_EMIT that->internalStateChanged(oldState, newState);
-
+    if( oldState < GST_STATE_PAUSED && newState > GST_STATE_READY ) // apply any changes that were done when playback was stopped
+    {
+        if( int( ( that->volume() + 0.005 ) * 100) != AmarokConfig::masterVolume()  )
+            that->setVolume( AmarokConfig::masterVolume() / 100.0 );
+        if( that->isMuted() != AmarokConfig::muteState() )
+            that->setMuted( AmarokConfig::muteState() );
+    }
     return true;
 }
 
@@ -857,8 +900,9 @@ EngineGstPipeline::handleEndOfStream()
         { // When working on EOS we do not want signals emitted to avoid bogus UI updates.
             Q_EMIT stateChanged(m_currentState, GST_STATE_READY);
             m_aboutToFinishWait.wakeAll();
-            //setState(GST_STATE_READY);
             Q_EMIT finished();
+            QMetaObject::invokeMethod(this, "setState", Qt::QueuedConnection, Q_ARG(GstState, GST_STATE_READY));
+
         }
         m_doingEOS = false;
     } else {
@@ -1111,8 +1155,7 @@ inline void EngineGstPipeline::analyzerConvertAndEmit(bool isEndOfMedia)
 
 
     for (int j = 0 ; j < m_channels ; ++j) {
-        // QVector::resize doesn't reallocate the buffer
-        m_analyzerChannelBuffers[j].resize(0);
+        m_analyzerChannelBuffers[j].clear();
     }
 }
 
@@ -1139,11 +1182,7 @@ void EngineGstPipeline::analyzerProcessBuffer(GstElement*, GstBuffer* buffer, Gs
     // TODO emit endOfMedia
     EngineGstPipeline *that = static_cast<EngineGstPipeline *>(gThat);
 
-    // Copied locally to avoid multithead problems
-    qint32 dataSize = that->m_analyzerDataSize;
-    if (dataSize == 0) {
-        return;
-    }
+    const qint32 dataSize = 512; // was m_dataSize in original phonon-gstreamer, hard-coded here to default 512
 
     int channelsCount = 0;
 
