@@ -19,7 +19,6 @@
 
 #include "amarok_export.h"
 #include "core/meta/forward_declarations.h"
-#include "core/support/SmartPointerList.h"
 
 #include <QAction>
 
@@ -36,7 +35,7 @@ class AMAROK_EXPORT GlobalCollectionGenreAction : public GlobalCollectionAction
     public:
 
         GlobalCollectionGenreAction( const QString &text, QObject * parent );
-        void setGenre( Meta::GenrePtr genre );
+        void setGenre( const Meta::GenrePtr &genre );
 
     protected:
         Meta::GenrePtr genre();
@@ -51,7 +50,7 @@ class AMAROK_EXPORT GlobalCollectionArtistAction : public GlobalCollectionAction
     public:
 
         GlobalCollectionArtistAction( const QString &text, QObject * parent );
-        void setArtist( Meta::ArtistPtr artist );
+        void setArtist( const Meta::ArtistPtr &artist );
         
     protected:
         Meta::ArtistPtr artist();
@@ -66,7 +65,7 @@ class AMAROK_EXPORT GlobalCollectionAlbumAction : public GlobalCollectionAction
     public:
 
         GlobalCollectionAlbumAction( const QString &text, QObject * parent );
-        void setAlbum( Meta::AlbumPtr album );
+        void setAlbum( const Meta::AlbumPtr &album );
 
     protected:
         Meta::AlbumPtr album();
@@ -81,7 +80,7 @@ class AMAROK_EXPORT GlobalCollectionTrackAction : public GlobalCollectionAction
     public:
 
         GlobalCollectionTrackAction( const QString &text, QObject * parent );
-        void setTrack( Meta::TrackPtr track );
+        void setTrack( const Meta::TrackPtr &track );
         
     protected:
         Meta::TrackPtr track();
@@ -96,7 +95,7 @@ class AMAROK_EXPORT GlobalCollectionYearAction : public GlobalCollectionAction
     public:
 
         GlobalCollectionYearAction( const QString &text, QObject * parent );
-        void setYear( Meta::YearPtr year );
+        void setYear( const Meta::YearPtr &year );
 
     protected:
         Meta::YearPtr year();
@@ -111,7 +110,7 @@ class GlobalCollectionComposerAction : public GlobalCollectionAction
     public:
 
         GlobalCollectionComposerAction( const QString &text, QObject * parent );
-        void setComposer( Meta::ComposerPtr composer );
+        void setComposer( const Meta::ComposerPtr &composer );
 
     protected:
         Meta::ComposerPtr composer();
@@ -130,12 +129,14 @@ namespace The {
 /**
   This class keeps track of global context actions that should be added to all genre, artists or another meta type in all collections.
 */
-class AMAROK_EXPORT GlobalCollectionActions
+class AMAROK_EXPORT GlobalCollectionActions : public QObject
 {
+    Q_OBJECT
+
     friend GlobalCollectionActions* The::globalCollectionActions();
 
 public:
-    QList<QAction *> actionsFor( Meta::DataPtr item );
+    QList<QAction *> actionsFor( const Meta::DataPtr &item );
 
     void addGenreAction( GlobalCollectionGenreAction * action );
     void addArtistAction( GlobalCollectionArtistAction * action );
@@ -146,21 +147,21 @@ public:
     
 private:
     GlobalCollectionActions();
-    ~GlobalCollectionActions();
+    ~GlobalCollectionActions() override;
 
-    QList<QAction *> actionsFor( Meta::GenrePtr genre );
-    QList<QAction *> actionsFor( Meta::ArtistPtr artist );
-    QList<QAction *> actionsFor( Meta::AlbumPtr album );
-    QList<QAction *> actionsFor( Meta::TrackPtr track );
-    QList<QAction *> actionsFor( Meta::YearPtr year );
-    QList<QAction *> actionsFor( Meta::ComposerPtr composer );
+    QList<QAction *> actionsFor( const Meta::GenrePtr &genre );
+    QList<QAction *> actionsFor( const Meta::ArtistPtr &artist );
+    QList<QAction *> actionsFor( const Meta::AlbumPtr &album );
+    QList<QAction *> actionsFor( const Meta::TrackPtr &track );
+    QList<QAction *> actionsFor( const Meta::YearPtr &year );
+    QList<QAction *> actionsFor( const Meta::ComposerPtr &composer );
 
-    SmartPointerList<GlobalCollectionGenreAction> m_genreActions;
-    SmartPointerList<GlobalCollectionArtistAction> m_artistActions;
-    SmartPointerList<GlobalCollectionAlbumAction> m_albumActions;
-    SmartPointerList<GlobalCollectionTrackAction> m_trackActions;
-    SmartPointerList<GlobalCollectionYearAction> m_yearActions;
-    SmartPointerList<GlobalCollectionComposerAction> m_composerActions;
+    QList<GlobalCollectionGenreAction*> m_genreActions;
+    QList<GlobalCollectionArtistAction*> m_artistActions;
+    QList<GlobalCollectionAlbumAction*> m_albumActions;
+    QList<GlobalCollectionTrackAction*> m_trackActions;
+    QList<GlobalCollectionYearAction*> m_yearActions;
+    QList<GlobalCollectionComposerAction*> m_composerActions;
 };
 
 #endif
