@@ -21,6 +21,7 @@
 #include "amarok_export.h"
 #include "OpmlOutline.h"
 
+#include <QHash>
 #include <QMap>
 #include <QStack>
 #include <QStringList>
@@ -160,21 +161,21 @@ private:
         public:
             explicit Action( ActionMap &actionMap )
                 : m_actionMap( actionMap )
-                , m_begin( 0 )
-                , m_end( 0 )
-                , m_characters( 0 ) {}
+                , m_begin( nullptr )
+                , m_end( nullptr )
+                , m_characters( nullptr ) {}
 
             Action(ActionMap &actionMap, ActionCallback begin)
                 : m_actionMap( actionMap )
                 , m_begin( begin )
-                , m_end( 0 )
-                , m_characters( 0 ) {}
+                , m_end( nullptr )
+                , m_characters( nullptr ) {}
 
             Action(ActionMap &actionMap, ActionCallback begin, ActionCallback end)
                 : m_actionMap( actionMap )
                 , m_begin( begin )
                 , m_end( end )
-                , m_characters( 0 ) {}
+                , m_characters( nullptr ) {}
 
             Action(ActionMap &actionMap, ActionCallback begin,
                     ActionCallback end, ActionCallback characters)
