@@ -20,8 +20,9 @@
 #include "amarok_export.h"
 
 #include <QObject>
-#include <QTreeView>
+#include <QPalette>
 
+class QAbstractItemView;
 class PaletteHandler;
 
 namespace The {
@@ -40,17 +41,25 @@ class AMAROK_EXPORT PaletteHandler : public QObject
 friend PaletteHandler* The::paletteHandler();
 
 public:
-    ~PaletteHandler();
+    ~PaletteHandler() override;
 
-    QPalette palette();
+    QPalette palette() const;
 
     void setPalette( const QPalette & palette );
+
+    /** Gives the item view a special darker palette and transparent background.
+        You need to connect to the newPalette signal afterwards because this
+        darker palette does not automatically update.
+        @param view the item view.
+    */
     void updateItemView( QAbstractItemView * view );
 
     /**
     * Returns the foreground color for the painter by checking the painting QWidget::foregroundRole() and falling back to
-    * QPalette::WindowText (or QPalette::HighlightedText if @param selected)
+    * QPalette::WindowText (or QPalette::HighlightedText if @p selected)
     * Uses the widgets palette or the application palette as fallback
+    * @param p the painter.
+    * @param selected the mode switcher.
     */    
     QColor foregroundColor( const QPainter *p, bool selected = false );
 
@@ -76,11 +85,11 @@ public:
      */
     static QColor alternateBackgroundColor();
 
-signals:
+Q_SIGNALS:
     void newPalette( const QPalette & palette );
 
 private:
-    PaletteHandler( QObject* parent = 0 );
+    PaletteHandler( QObject* parent = nullptr );
 
     QPalette m_palette;
 };
