@@ -69,12 +69,12 @@ void AmarokUrl::initFromString( const QString & urlString )
 
     if ( !argumentsString.isEmpty() )
     {
-        parts = argumentsString.split( '&' );
+        parts = argumentsString.split( QLatin1Char( '&' ) );
         
-        foreach( const QString &argument, parts )
+        for( const QString &argument : parts )
         {
             
-            QStringList argParts = argument.split( '=' );
+            QStringList argParts = argument.split( QLatin1Char( '=' ) );
             debug() << "argument: " << argument << " unescaped: " << unescape( argParts.at( 1 ) );
             setArg( argParts.at( 0 ), unescape( argParts.at( 1 ) ) );
         }
@@ -127,14 +127,14 @@ QString AmarokUrl::url() const
     QUrl url;
     url.setScheme( QStringLiteral("amarok") );
     url.setHost( m_command );
-    url.setPath( '/' + m_path ); // the path must begin by /
+    url.setPath( QLatin1Char( '/' ) + m_path ); // the path must begin by /
     QUrlQuery query;
 
-    foreach( const QString &argName, m_arguments.keys() )
+    for( const QString &argName : m_arguments.keys() )
         query.addQueryItem( argName, m_arguments[argName] );
 
     url.setQuery( query );
-    return url.toEncoded();
+    return url.toString( QUrl::FullyEncoded );
 }
 
 bool AmarokUrl::saveToDb()
@@ -164,7 +164,7 @@ bool AmarokUrl::saveToDb()
         QString query = QStringLiteral("INSERT INTO bookmarks ( parent_id, name, url, description, custom ) VALUES ( %1, '%2', '%3', '%4', '%5' );");
         query = query.arg( QString::number( parentId ), sql->escape( m_name ), sql->escape( url() ),
                            sql->escape( m_description ), sql->escape( m_customValue ) );
-        m_id = StorageManager::instance()->sqlStorage()->insert( query, nullptr );
+        m_id = StorageManager::instance()->sqlStorage()->insert( query, QString() );
     }
 
     return true;
@@ -222,7 +222,7 @@ QString AmarokUrl::customValue() const
 
 QString AmarokUrl::escape( const QString & in )
 {
-    return QUrl::toPercentEncoding( in.toUtf8() );
+    return QString::fromLatin1( QUrl::toPercentEncoding( in ) );
 }
 
 QString AmarokUrl::unescape( const QString & in )
