@@ -24,13 +24,13 @@
 #include <QString>
 #include <QStringList>
 
-#include <KSharedPtr>
+#include "AmarokSharedPointer.h"
 
 class BookmarkGroup;
 class AmarokUrl;
 
-typedef KSharedPtr<AmarokUrl> AmarokUrlPtr;
-typedef KSharedPtr<BookmarkGroup> BookmarkGroupPtr;
+typedef AmarokSharedPointer<AmarokUrl> AmarokUrlPtr;
+typedef AmarokSharedPointer<BookmarkGroup> BookmarkGroupPtr;
 typedef QList<AmarokUrlPtr> BookmarkList;
 typedef QList<BookmarkGroupPtr> BookmarkGroupList;
 
@@ -41,34 +41,34 @@ A class for allowing a "folder structure" in the bookmark browser and the databa
 class BookmarkGroup : public BookmarkViewItem
 {
     public:
-        BookmarkGroup( const QStringList &dbResultRow, BookmarkGroupPtr parent );
-        explicit BookmarkGroup( const QString &name, BookmarkGroupPtr parent = BookmarkGroupPtr() );
+        BookmarkGroup( const QStringList &dbResultRow, const BookmarkGroupPtr &parent );
+        explicit BookmarkGroup( const QString &name, const BookmarkGroupPtr &parent = BookmarkGroupPtr() );
 
         BookmarkGroup( const QString &name, const QString &customType );
 
-        ~BookmarkGroup();
+        ~BookmarkGroup() override;
 
         int id() const;
-        QString name() const;
-        QString description() const;
+        QString name() const override;
+        QString description() const override;
 
-        virtual int childCount() const;
+        int childCount() const override;
 
-        virtual BookmarkGroupPtr parent() const { return m_parent; }
+        BookmarkGroupPtr parent() const override { return m_parent; }
 
-        virtual void rename( const QString &name );
-        virtual void setDescription( const QString &description );
+        void rename( const QString &name ) override;
+        void setDescription( const QString &description ) override;
 
         void save();
         BookmarkGroupList childGroups() const;
         BookmarkList childBookmarks() const;
 
-        void reparent( BookmarkGroupPtr parent );
+        void reparent( const BookmarkGroupPtr &parent );
 
         void clear();
 
-        void deleteChild( BookmarkViewItemPtr item );
-        virtual void removeFromDb();
+        void deleteChild( const BookmarkViewItemPtr &item );
+        void removeFromDb() override;
 
     private:
         int m_dbId;
