@@ -25,9 +25,8 @@
 #include <core-impl/storage/StorageManager.h>
 #include <core/storage/SqlStorage.h>
 
-#include <QIcon>
-
 #include <QAbstractListModel>
+#include <QIcon>
 #include <QListIterator>
 
 #include <typeinfo>
@@ -331,7 +330,7 @@ BookmarkModel::mimeData( const QModelIndexList &indexes ) const
     BookmarkGroupList groups;
     BookmarkList bookmarks;
 
-    foreach( const QModelIndex &index, indexes ) {
+    for( const QModelIndex &index : indexes ) {
 
         BookmarkViewItemPtr item = m_viewItems.value( index.internalId() );
 
@@ -380,7 +379,7 @@ BookmarkModel::dropMimeData ( const QMimeData * data, Qt::DropAction action, int
 
             BookmarkGroupList groups = bookmarkGroupDrag->bookmarkGroups();
 
-            foreach( BookmarkGroupPtr group, groups ) {
+            for( BookmarkGroupPtr group : groups ) {
                 group->reparent( parentGroup );
             }
 
@@ -398,7 +397,7 @@ BookmarkModel::dropMimeData ( const QMimeData * data, Qt::DropAction action, int
         {
             BookmarkList bookmarks = dragList->bookmarks();
 
-            foreach( AmarokUrlPtr bookmarkPtr, bookmarks ) {
+            for( AmarokUrlPtr bookmarkPtr : bookmarks ) {
                 bookmarkPtr->reparent( parentGroup );
             }
 
@@ -419,20 +418,20 @@ void BookmarkModel::createTables()
     if( !sqlStorage )
         return;
 
-    sqlStorage->query( QString( "CREATE TABLE bookmark_groups ("
-            " id " + sqlStorage->idType() +
-            ", parent_id INTEGER"
-            ", name " + sqlStorage->textColumnType() +
-            ", description " + sqlStorage->textColumnType() +
-            ", custom " + sqlStorage->textColumnType() + " ) ENGINE = MyISAM;" ) );
+    sqlStorage->query( QStringLiteral( "CREATE TABLE bookmark_groups ("
+            " id ") + sqlStorage->idType() +
+            QStringLiteral(", parent_id INTEGER"
+            ", name ") + sqlStorage->textColumnType() +
+            QStringLiteral(", description ") + sqlStorage->textColumnType() +
+            QStringLiteral(", custom ") + sqlStorage->textColumnType() + QStringLiteral(" ) ENGINE = MyISAM;") );
 
-    sqlStorage->query( QString( "CREATE TABLE bookmarks ("
-            " id " + sqlStorage->idType() +
-            ", parent_id INTEGER"
-            ", name " + sqlStorage->textColumnType() +
-            ", url " + sqlStorage->exactTextColumnType() +
-            ", description " + sqlStorage->exactTextColumnType() +
-            ", custom " + sqlStorage->textColumnType() + " ) ENGINE = MyISAM;" ) );
+    sqlStorage->query( QStringLiteral( "CREATE TABLE bookmarks ("
+            " id ") + sqlStorage->idType() +
+            QStringLiteral(", parent_id INTEGER"
+            ", name ") + sqlStorage->textColumnType() +
+            QStringLiteral(", url ") + sqlStorage->exactTextColumnType() +
+            QStringLiteral(", description ") + sqlStorage->exactTextColumnType() +
+            QStringLiteral(", custom ") + sqlStorage->textColumnType() + QStringLiteral(" ) ENGINE = MyISAM;") );
 
 }
 
@@ -468,13 +467,13 @@ void BookmarkModel::checkTables()
     {
         debug() << "creating Playlist Tables";
         createTables();
-        sqlStorage->query( "INSERT INTO admin(component,version) "
-                "VALUES('" + key + "'," + QString::number( BOOKMARK_DB_VERSION ) + ");" );
+        sqlStorage->query( QStringLiteral("INSERT INTO admin(component,version) "
+                "VALUES('") + key + QStringLiteral("',") + QString::number( BOOKMARK_DB_VERSION ) + QStringLiteral(");") );
     }
     else if ( values.at( 0 ).toInt() < 4 )
     {
         upgradeTables( values.at( 0 ).toInt() );
-        sqlStorage->query( "UPDATE admin SET version=" + QString::number( BOOKMARK_DB_VERSION ) + " WHERE component=" + key + ';' );
+        sqlStorage->query( QStringLiteral("UPDATE admin SET version=") + QString::number( BOOKMARK_DB_VERSION ) + QStringLiteral(" WHERE component=") + key + QLatin1Char(';') );
     }
 }
 
@@ -495,7 +494,7 @@ BookmarkModel::editBookmark( int id )
 
   //for now, assume that the newly added playlist is in the top level:
     int row = m_root->childGroups().count() - 1;
-    foreach ( AmarokUrlPtr bookmark, m_root->childBookmarks() ) {
+    for ( AmarokUrlPtr bookmark : m_root->childBookmarks() ) {
         row++;
         if ( bookmark->id() == id ) {
             Q_EMIT editIndex( createIndex( row , 0, BookmarkViewItemPtr::staticCast( bookmark ) ) );
@@ -516,7 +515,7 @@ BookmarkModel::createNewGroup()
     reloadFromDb();
 
     int row = 0;
-    foreach ( BookmarkGroupPtr childGroup, m_root->childGroups() ) {
+    for ( BookmarkGroupPtr childGroup : m_root->childGroups() ) {
         if ( childGroup->id() == id )
         {
             debug() << "emitting edit for " << childGroup->name() << " id " << childGroup->id() << " in row " << row;
@@ -542,7 +541,7 @@ BookmarkModel::createNewBookmark()
     reloadFromDb();
     debug() << "id of new bookmark: " << id;
     int row = m_root->childGroups().count();
-    foreach ( AmarokUrlPtr childBookmark, m_root->childBookmarks() ) {
+    for ( AmarokUrlPtr childBookmark : m_root->childBookmarks() ) {
         debug() << id << " == " << childBookmark->id() << " ? ";
         if ( childBookmark->id() == id )
         {
@@ -607,7 +606,7 @@ BookmarkModel::renameBookmark( const QString& oldName, const QString& newName )
 bool
 BookmarkModel::setBookmarkArgRecursively(  BookmarkGroupPtr group, const QString& name, const QString& key, const QString &value )
 {
-    foreach( AmarokUrlPtr item, group->childBookmarks() )
+    for( AmarokUrlPtr item : group->childBookmarks() )
     {
         if( item->name() == name )
         {
@@ -618,7 +617,7 @@ BookmarkModel::setBookmarkArgRecursively(  BookmarkGroupPtr group, const QString
     }
 
     //if not found, recurse through child groups
-    foreach( BookmarkGroupPtr childGroup, group->childGroups() )
+    for( BookmarkGroupPtr childGroup : group->childGroups() )
     {
         if( setBookmarkArgRecursively( childGroup, name, key, value ) )
             return true;
@@ -631,7 +630,7 @@ BookmarkModel::setBookmarkArgRecursively(  BookmarkGroupPtr group, const QString
 bool
 BookmarkModel::deleteBookmarkRecursively( BookmarkGroupPtr group, const QString& name )
 {
-    foreach( AmarokUrlPtr item, group->childBookmarks() )
+    for( AmarokUrlPtr item : group->childBookmarks() )
     {
         debug() << "item->name(): " << item->name();
         if( item->name() == name )
@@ -643,7 +642,7 @@ BookmarkModel::deleteBookmarkRecursively( BookmarkGroupPtr group, const QString&
     }
 
     //if not found, recurse through child groups
-    foreach( BookmarkGroupPtr childGroup, group->childGroups() )
+    for( BookmarkGroupPtr childGroup : group->childGroups() )
     {
         if( deleteBookmarkRecursively( childGroup, name ) )
             return true;
@@ -656,7 +655,7 @@ BookmarkModel::deleteBookmarkRecursively( BookmarkGroupPtr group, const QString&
 bool
 BookmarkModel::renameBookmarkRecursively( BookmarkGroupPtr group, const QString& oldName, const QString& newName )
 {
-    foreach( AmarokUrlPtr item, group->childBookmarks() )
+    for( AmarokUrlPtr item : group->childBookmarks() )
     {
         debug() << "item->name(): " << item->name();
         if( item->name() == oldName)
@@ -668,7 +667,7 @@ BookmarkModel::renameBookmarkRecursively( BookmarkGroupPtr group, const QString&
     }
 
     //if not found, recurse through child groups
-    foreach( BookmarkGroupPtr childGroup, group->childGroups() )
+    for( BookmarkGroupPtr childGroup : group->childGroups() )
     {
         if( renameBookmarkRecursively( childGroup, oldName, newName ) )
             return true;
@@ -685,10 +684,10 @@ void BookmarkModel::upgradeTables( int from )
         return;
     
     if ( from == 2 ) {
-        sqlStorage->query( "ALTER TABLE bookmarks ADD custom " + sqlStorage->textColumnType() + ';' );
+        sqlStorage->query( QStringLiteral("ALTER TABLE bookmarks ADD custom ") + sqlStorage->textColumnType() + QLatin1Char(';') );
     }
 
-    sqlStorage->query( "ALTER TABLE bookmark_groups ADD custom " + sqlStorage->textColumnType() + ';' );
+    sqlStorage->query( QStringLiteral("ALTER TABLE bookmark_groups ADD custom ") + sqlStorage->textColumnType() + QLatin1Char(';') );
 } 
 
 
