@@ -91,14 +91,14 @@ BookmarkList PlayUrlRunner::bookmarksFromUrl( const QUrl &url )
     BookmarkList list;
 
     //See PlayUrlGenerator for the description of a 'play' amarokurl
-    QString track_encoded = url.toEncoded().toBase64();
+    QString track_encoded = QLatin1String( url.toEncoded().toBase64() );
 
     // The last character of a base64 encoded string is always '=', which
     // chokes the SQL. Since we are using a substring like text comparison
     // and every url in the database will have the '=', just chop it off.
 
     // some tracks even seem to have multiple '='s at the end... chop them all off!
-    while( track_encoded.endsWith( '=' ) )
+    while( track_encoded.endsWith( QLatin1Char('=') ) )
         track_encoded.chop ( 1 );
 
     // Queries the database for bookmarks where the url field contains
