@@ -30,11 +30,12 @@ class AMAROK_EXPORT PlayUrlRunner : public AmarokUrlRunnerBase
 public:
     PlayUrlRunner ();
 
-    virtual  ~PlayUrlRunner ();
+    ~PlayUrlRunner () override;
 
-    virtual QString command () const;
-    virtual bool run ( AmarokUrl url );
-    virtual KIcon icon () const;
+    QString command () const override;
+    QString prettyCommand() const override;
+    bool run ( const AmarokUrl &url ) override;
+    QIcon icon () const override;
 
     /**
      * This function takes a url for a track, and returns a list
@@ -45,7 +46,7 @@ public:
      * @return a list of bookmarks. the list is empty if no bookmarks exist.
      * @see PlayUrlGenerator
      */
-    static BookmarkList bookmarksFromUrl( KUrl url );
+    static BookmarkList bookmarksFromUrl( const QUrl &url );
 
 };
 
