@@ -21,8 +21,6 @@
 #include "core/support/Debug.h"
 #include "widgets/BreadcrumbItemButton.h"
 
-#include <QDir>
-#include <QHBoxLayout>
 #include <QIcon>
 #include <QMenu>
 
@@ -47,7 +45,7 @@ BrowserBreadcrumbItem::BrowserBreadcrumbItem( BrowserCategory *category, QWidget
 
         const QStringList siblingNames = siblingMap.keys();
 
-        foreach( const QString &siblingName, siblingNames )
+        for( const QString &siblingName : siblingNames )
         {
             //no point in adding ourselves to this menu
             if ( siblingName == category->name() )
@@ -104,10 +102,10 @@ BrowserBreadcrumbItem::BrowserBreadcrumbItem( const QString &name, const QString
         m_menuButton = new BreadcrumbItemMenuButton( this );
         QMenu *menu = new QMenu( this );
 
-        foreach( const BreadcrumbSibling &sibling, childItems )
+        for( const BreadcrumbSibling &sibling : childItems )
         {
             QString visibleName = sibling.name;
-            visibleName.replace( '&', QLatin1String("&&") ); // prevent bug 244817
+            visibleName.replace( QLatin1Char('&'), QLatin1String("&&") ); // prevent bug 244817
             QAction *action = menu->addAction( sibling.icon, visibleName );
             action->setProperty( "callback", sibling.callback );
 
