@@ -22,7 +22,6 @@
 #include "EngineController.h"
 #include "PaletteHandler.h"
 #include "PopupDropperFactory.h"
-#include "SvgHandler.h"
 #include "context/ContextView.h"
 #include "core/playlists/PlaylistFormat.h"
 #include "core/support/Debug.h"
@@ -35,14 +34,10 @@
 
 #include <QAction>
 #include <QContextMenuEvent>
-#include <QFileSystemModel>
 #include <QIcon>
-#include <QItemDelegate>
 #include <QMenu>
-#include <QPainter>
 #include <QUrl>
 
-#include <KConfigGroup>
 #include <KDirModel>
 #include <KFileItem>
 #include <KIO/CopyJob>
@@ -81,7 +76,7 @@ FileView::contextMenuEvent( QContextMenuEvent *e )
         return;
 
     //trying to do fancy stuff while showing places only leads to tears!
-    if( model()->objectName() == "PLACESMODEL" )
+    if( model()->objectName() == QStringLiteral("PLACESMODEL") )
     {
         e->accept();
         return;
@@ -93,7 +88,7 @@ FileView::contextMenuEvent( QContextMenuEvent *e )
         return;
 
     QMenu menu;
-    foreach( QAction *action, actionsForIndices( indices, PlaylistAction ) )
+    for( QAction *action : actionsForIndices( indices, PlaylistAction ) )
         menu.addAction( action );
     menu.addSeparator();
 
@@ -115,7 +110,7 @@ FileView::contextMenuEvent( QContextMenuEvent *e )
     {
         QMenu *copyMenu = new QMenu( i18n( ("Copy to Collection") ), &menu );
         copyMenu->setIcon( QIcon::fromTheme( QStringLiteral("edit-copy") ) );
-        foreach( Collections::Collection *coll, writableCollections )
+        for( Collections::Collection *coll : writableCollections )
         {
             CollectionAction *copyAction = new CollectionAction( coll, &menu );
             connect( copyAction, &QAction::triggered, this, &FileView::slotPrepareCopyTracks );
@@ -125,7 +120,7 @@ FileView::contextMenuEvent( QContextMenuEvent *e )
 
         QMenu *moveMenu = new QMenu( i18n( "Move to Collection" ), &menu );
         moveMenu->setIcon( QIcon::fromTheme( QStringLiteral("go-jump") ) );
-        foreach( Collections::Collection *coll, writableCollections )
+        for( Collections::Collection *coll : writableCollections )
         {
             CollectionAction *moveAction = new CollectionAction( coll, &menu );
             connect( moveAction, &QAction::triggered, this, &FileView::slotPrepareMoveTracks );
@@ -133,11 +128,11 @@ FileView::contextMenuEvent( QContextMenuEvent *e )
         }
         menu.addMenu( moveMenu );
     }
-    foreach( QAction *action, actionsForIndices( indices, OrganizeAction ) )
+    for( QAction *action : actionsForIndices( indices, OrganizeAction ) )
         menu.addAction( action );
     menu.addSeparator();
 
-    foreach( QAction *action, actionsForIndices( indices, EditAction ) )
+    for( QAction *action : actionsForIndices( indices, EditAction ) )
         menu.addAction( action );
 
     menu.exec( e->globalPos() );
@@ -153,7 +148,7 @@ FileView::mouseReleaseEvent( QMouseEvent *event )
         return;
     }
 
-    if( state() == QAbstractItemView::NoState && event->button() == Qt::MidButton )
+    if( state() == QAbstractItemView::NoState && event->button() == Qt::MiddleButton )
     {
         addIndexToPlaylist( index, Playlist::OnMiddleClickOnSelectedItems );
         event->accept();
@@ -186,7 +181,7 @@ FileView::mouseDoubleClickEvent( QMouseEvent *event )
     }
 
     // swallow middle-button double-clicks
-    if( event->button() == Qt::MidButton )
+    if( event->button() == Qt::MiddleButton )
     {
         event->accept();
         return;
@@ -317,7 +312,7 @@ FileView::slotCopyTracks( const Meta::TrackList& tracks )
         return;
 
     QSet<Collections::Collection *> collections;
-    foreach( const Meta::TrackPtr &track, tracks )
+    for( const Meta::TrackPtr &track : tracks )
     {
         collections.insert( track->collection() );
     }
@@ -347,7 +342,7 @@ FileView::slotMoveTracks( const Meta::TrackList& tracks )
         return;
 
     QSet<Collections::Collection *> collections;
-    foreach( const Meta::TrackPtr &track, tracks )
+    for( const Meta::TrackPtr &track : tracks )
     {
         collections.insert( track->collection() );
     }
@@ -380,9 +375,9 @@ FileView::actionsForIndices( const QModelIndexList &indices, ActionType type )
 
     if( !m_appendAction )
     {
-        m_appendAction = new QAction( QIcon::fromTheme( "media-track-add-amarok" ), i18n( "&Add to Playlist" ),
+        m_appendAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-add-amarok") ), i18n( "&Add to Playlist" ),
                                       this );
-        m_appendAction->setProperty( "popupdropper_svg_id", "append" );
+        m_appendAction->setProperty( "popupdropper_svg_id", QStringLiteral("append") );
         connect( m_appendAction, &QAction::triggered, this, &FileView::slotAppendToPlaylist );
     }
     if( type & PlaylistAction )
@@ -392,7 +387,7 @@ FileView::actionsForIndices( const QModelIndexList &indices, ActionType type )
     {
         m_loadAction = new QAction( i18nc( "Replace the currently loaded tracks with these",
                                            "&Replace Playlist" ), this );
-        m_loadAction->setProperty( "popupdropper_svg_id", "load" );
+        m_loadAction->setProperty( "popupdropper_svg_id", QStringLiteral("load") );
         connect( m_loadAction, &QAction::triggered, this, &FileView::slotReplacePlaylist );
     }
     if( type & PlaylistAction )
@@ -400,8 +395,8 @@ FileView::actionsForIndices( const QModelIndexList &indices, ActionType type )
 
     if( !m_moveToTrashAction )
     {
-        m_moveToTrashAction = new QAction( QIcon::fromTheme( "user-trash" ), i18n( "&Move to Trash" ), this );
-        m_moveToTrashAction->setProperty( "popupdropper_svg_id", "delete_file" );
+        m_moveToTrashAction = new QAction( QIcon::fromTheme( QStringLiteral("user-trash") ), i18n( "&Move to Trash" ), this );
+        m_moveToTrashAction->setProperty( "popupdropper_svg_id", QStringLiteral("delete_file") );
         // key shortcut is only for display purposes here, actual one is determined by View in Model/View classes
         m_moveToTrashAction->setShortcut( Qt::Key_Delete );
         connect( m_moveToTrashAction, &QAction::triggered, this, &FileView::slotMoveToTrashWithoutModifiers );
@@ -411,10 +406,10 @@ FileView::actionsForIndices( const QModelIndexList &indices, ActionType type )
 
     if( !m_deleteAction )
     {
-        m_deleteAction = new QAction( QIcon::fromTheme( "remove-amarok" ), i18n( "&Delete" ), this );
-        m_deleteAction->setProperty( "popupdropper_svg_id", "delete_file" );
+        m_deleteAction = new QAction( QIcon::fromTheme( QStringLiteral("remove-amarok") ), i18n( "&Delete" ), this );
+        m_deleteAction->setProperty( "popupdropper_svg_id", QStringLiteral("delete_file") );
         // key shortcut is only for display purposes here, actual one is determined by View in Model/View classes
-        m_deleteAction->setShortcut( Qt::SHIFT + Qt::Key_Delete );
+        m_deleteAction->setShortcut( Qt::SHIFT | Qt::Key_Delete );
         connect( m_deleteAction, &QAction::triggered, this, &FileView::slotDelete );
     }
     if( type & OrganizeAction )
@@ -422,9 +417,9 @@ FileView::actionsForIndices( const QModelIndexList &indices, ActionType type )
 
     if( !m_editAction )
     {
-        m_editAction = new QAction( QIcon::fromTheme( "media-track-edit-amarok" ),
+        m_editAction = new QAction( QIcon::fromTheme( QStringLiteral("media-track-edit-amarok") ),
                                     i18n( "&Edit Track Details" ), this );
-        m_editAction->setProperty( "popupdropper_svg_id", "edit" );
+        m_editAction->setProperty( "popupdropper_svg_id", QStringLiteral("edit") );
         connect( m_editAction, &QAction::triggered, this, &FileView::slotEditTracks );
     }
     if( type & EditAction )
@@ -459,7 +454,7 @@ FileView::addIndicesToPlaylist( QModelIndexList indices, Playlist::AddOptions op
     std::sort( indices.begin(), indices.end() );
 
     QList<QUrl> urls;
-    foreach( const QModelIndex &index, indices )
+    for( const QModelIndex &index : indices )
     {
         KFileItem file = index.data( KDirModel::FileItemRole ).value<KFileItem>();
         QUrl url = file.url();
@@ -499,7 +494,7 @@ FileView::startDrag( Qt::DropActions supportedActions )
         font.setPointSize( 16 );
         font.setBold( true );
 
-        foreach( QAction *action, actions )
+        for( QAction *action : actions )
             m_pd->addItem( The::popupDropperFactory()->createItem( action ) );
 
         m_pd->show();
@@ -526,7 +521,7 @@ FileView::selectedItems() const
     if( indices.isEmpty() )
         return items;
 
-    foreach( const QModelIndex& index, indices )
+    for( const QModelIndex &index : indices )
     {
         KFileItem item = index.data( KDirModel::FileItemRole ).value<KFileItem>();
         items << item;
@@ -543,7 +538,7 @@ FileView::tracksForEdit() const
     if( indices.isEmpty() )
         return tracks;
 
-    foreach( const QModelIndex &index, indices )
+    for( const QModelIndex &index : indices )
     {
         KFileItem item = index.data( KDirModel::FileItemRole ).value<KFileItem>();
         Meta::TrackPtr track = CollectionManager::instance()->trackForUrl( item.url() );
@@ -583,7 +578,7 @@ FileView::slotMoveToTrash( Qt::MouseButtons buttons, Qt::KeyboardModifiers modif
 
     QList<QUrl> urls;
     QStringList filepaths;
-    foreach( const QModelIndex& index, indices )
+    for( const QModelIndex &index : indices )
     {
         KFileItem file = index.data( KDirModel::FileItemRole ).value<KFileItem>();
         filepaths << file.localPath();
