@@ -38,7 +38,7 @@ class PopupDropper;
 class CollectionAction : public QAction
 {
     public:
-        explicit CollectionAction( Collections::Collection *coll, QObject *parent = 0 )
+        explicit CollectionAction( Collections::Collection *coll, QObject *parent = nullptr )
         : QAction( parent )
         , m_collection( coll )
         {
@@ -60,13 +60,13 @@ class FileView : public Amarok::PrettyTreeView
     Q_OBJECT
 
 public:
-    FileView( QWidget *parent );
+    explicit FileView( QWidget *parent );
 
-signals:
+Q_SIGNALS:
     void navigateToDirectory( const QModelIndex &index );
     void refreshBrowser();
 
-protected slots:
+protected Q_SLOTS:
     void slotAppendToPlaylist();
     void slotReplacePlaylist();
     void slotEditTracks();
@@ -75,6 +75,7 @@ protected slots:
     void slotMoveTracks( const Meta::TrackList &tracks );
     void slotCopyTracks( const Meta::TrackList &tracks );
     void slotMoveToTrash( Qt::MouseButtons buttons, Qt::KeyboardModifiers modifiers );
+    void slotMoveToTrashWithoutModifiers() { slotMoveToTrash( Qt::NoButton, Qt::NoModifier ); }
     void slotDelete();
 
 protected:
@@ -93,13 +94,13 @@ protected:
     void addIndexToPlaylist( const QModelIndex &idx, Playlist::AddOptions options );
     void addIndicesToPlaylist( QModelIndexList indices, Playlist::AddOptions options );
 
-    virtual void contextMenuEvent( QContextMenuEvent *e );
-    virtual void mouseReleaseEvent( QMouseEvent *event );
-    virtual void mouseDoubleClickEvent( QMouseEvent *event );
+    void contextMenuEvent( QContextMenuEvent *e ) override;
+    void mouseReleaseEvent( QMouseEvent *event ) override;
+    void mouseDoubleClickEvent( QMouseEvent *event ) override;
 
-    virtual void keyPressEvent( QKeyEvent *event );
+    void keyPressEvent( QKeyEvent *event ) override;
 
-    virtual void startDrag( Qt::DropActions supportedActions );
+    void startDrag( Qt::DropActions supportedActions ) override;
     KFileItemList selectedItems() const;
 
 private:
@@ -114,8 +115,8 @@ private:
     PopupDropper *m_pd;
     QMutex m_dragMutex;
     bool m_ongoingDrag;
-    QWeakPointer<Collections::Collection> m_moveDestinationCollection;
-    QWeakPointer<Collections::Collection> m_copyDestinationCollection;
+    QPointer<Collections::Collection> m_moveDestinationCollection;
+    QPointer<Collections::Collection> m_copyDestinationCollection;
 };
 
 #endif // end include guard
