@@ -21,21 +21,21 @@
 #include "core/meta/PlaylistGroup.h"
 
 #include <QSharedData>
-#include <KSharedPtr>
+#include "AmarokSharedPointer.h"
 
 /**
 	@author Nikolaj Hald Nielsen <nhn@kde.org>
 */
 
 class PlaylistViewItem;
-typedef KSharedPtr<PlaylistViewItem> PlaylistViewItemPtr;
+typedef AmarokSharedPointer<PlaylistViewItem> PlaylistViewItemPtr;
 
 class PlaylistViewItem : public virtual QSharedData
 {
     public:
         PlaylistViewItem() : QSharedData() {}
 
-        virtual  ~PlaylistViewItem() {};
+        virtual  ~PlaylistViewItem() {}
 
         virtual Meta::PlaylistGroupPtr parent() const = 0;
         virtual int childCount() const { return 0; }
