@@ -25,12 +25,12 @@ class GeneralConfig : public ConfigDialogBase, public Ui_GeneralConfig
     Q_OBJECT
 
     public:
-        GeneralConfig( QWidget* parent );
-        virtual ~GeneralConfig();
+        explicit GeneralConfig( Amarok2ConfigDialog* parent );
+        ~GeneralConfig() override;
 
-        virtual bool hasChanged();
-        virtual bool isDefault();
-        virtual void updateSettings();
+        bool hasChanged() override;
+        bool isDefault() override;
+        void updateSettings() override;
 };
 
 #endif
