@@ -29,17 +29,17 @@ class NotificationsConfig : public ConfigDialogBase, public Ui_NotificationsConf
     Q_OBJECT
 
     public:
-        NotificationsConfig( QWidget* parent );
-        virtual ~NotificationsConfig();
+        explicit NotificationsConfig( Amarok2ConfigDialog* parent );
+        ~NotificationsConfig() override;
 
-        virtual bool hasChanged();
-        virtual bool isDefault();
-        virtual void updateSettings();
+        bool hasChanged() override;
+        bool isDefault() override;
+        void updateSettings() override;
 
-    signals:
+    Q_SIGNALS:
         void changed();
 
-    private slots:
+    private Q_SLOTS:
         void slotPositionChanged();
         void useCustomColorsToggled( bool );
         void setGrowlEnabled( bool );
@@ -50,8 +50,8 @@ class NotificationsConfig : public ConfigDialogBase, public Ui_NotificationsConf
         OSDWidget::Alignment m_oldAlignment;
         uint m_oldYOffset;
 
-        void hideEvent( QHideEvent* );
-        void showEvent( QShowEvent* );
+        void hideEvent( QHideEvent* ) override;
+        void showEvent( QShowEvent* ) override;
 };
 
 #endif
