@@ -33,7 +33,7 @@ PlaybackConfig::PlaybackConfig( Amarok2ConfigDialog* parent )
     Q_ASSERT( engine );
     if( !engine->supportsFadeout() )
     {
-        const QString toolTip = i18n( "Current Phonon backend does not support volume fading" );
+        const QString toolTip = i18n( "Current audio backend does not support volume fading" );
         kcfg_FadeoutOnStop->setEnabled( false );
         kcfg_FadeoutOnStop->setToolTip( toolTip );
         kcfg_FadeoutOnPause->setEnabled( false );
