@@ -65,10 +65,10 @@ AlbumsModel::data( const QModelIndex &index, int role ) const
             int year     = album->data( AlbumYearRole ).toInt();
 
             QStringList texts;
-            texts << ((year > 0) ? QString( "%1 (%2)" ).arg( name, QString::number(year) ) : name).toHtmlEscaped();
+            texts << ((year > 0) ? QStringLiteral( "%1 (%2)" ).arg( name, QString::number(year) ) : name).toHtmlEscaped();
             texts << album->data( AlbumLengthRole ).toString().toHtmlEscaped();
 
-            return texts.join("<br>");
+            return texts.join(QStringLiteral("<br>"));
         }
 
         if( const auto track = dynamic_cast<const TrackItem *>( item ) )
@@ -76,16 +76,16 @@ AlbumsModel::data( const QModelIndex &index, int role ) const
             bool isCompilation = track->data( AlbumCompilationRole ).toBool();
             const QString &name = track->data( NameRole ).toString();
             const QString &artist = track->data( TrackArtistRole ).toString();
-            QString length = " (" + Meta::msToPrettyTime( track->data( TrackLengthRole ).toInt() ) + ')';
-            QString number = track->data( TrackNumberRole ).toString() + ". ";
-            QString middle = isCompilation ? QString( "%1 - %2" ).arg( artist, name ) : name;
+            QString length = QStringLiteral(" (") + Meta::msToPrettyTime( track->data( TrackLengthRole ).toInt() ) + QLatin1Char(')');
+            QString number = track->data( TrackNumberRole ).toString() + QStringLiteral(". ");
+            QString middle = isCompilation ? QStringLiteral( "%1 - %2" ).arg( artist, name ) : name;
 
-            QString ret = QStringList( { number, middle, length } ).join( ' ' ).toHtmlEscaped();
+            QString ret = QStringList( { number, middle, length } ).join( QLatin1Char(' ') ).toHtmlEscaped();
             // Styling to indicate current track and artist in listings
             if( track->bold() )
-                ret = "<b>" + ret + "</b>";
+                ret = QStringLiteral("<b>") + ret + QStringLiteral("</b>");
             if( track->italic() )
-                ret = "<i>" + ret + "</i>";
+                ret = QStringLiteral("<i>") + ret + QStringLiteral("</i>");
             return ret;
         }
     }
@@ -108,7 +108,7 @@ AlbumsModel::mimeData( const QModelIndexList &indices ) const
         return nullptr;
 
     Meta::TrackList tracks;
-    foreach( const QModelIndex &index, indices )
+    for( const QModelIndex &index : indices )
         tracks << tracksForIndex( index );
     QSet< AmarokSharedPointer<Meta::Track> > tracksSet(tracks.begin(), tracks.end());
     tracks = tracksSet.values();
@@ -180,10 +180,10 @@ AlbumsProxyModel::lessThan( const QModelIndex &left, const QModelIndex &right )
         const AlbumItem *leftAlbum = static_cast<const AlbumItem *>( leftItem );
         const AlbumItem *rightAlbum = static_cast<const AlbumItem *>( model->itemFromIndex( right ) );
         QDateTime leftMaxCreateDate, rightMaxCreateDate;
-        foreach( Meta::TrackPtr track, leftAlbum->album()->tracks() )
+        for( Meta::TrackPtr track : leftAlbum->album()->tracks() )
             if( track->createDate() > leftMaxCreateDate )
                 leftMaxCreateDate = track->createDate();
-        foreach( Meta::TrackPtr track, rightAlbum->album()->tracks() )
+        for( Meta::TrackPtr track : rightAlbum->album()->tracks() )
             if( track->createDate() > rightMaxCreateDate )
                 rightMaxCreateDate = track->createDate();
         return leftMaxCreateDate > rightMaxCreateDate;
@@ -203,7 +203,7 @@ AlbumsProxyModel::filterAcceptsRow( int sourceRow, const QModelIndex &sourcePare
     const QModelIndex &srcIndex     = sourceModel()->index( sourceRow, 0, sourceParent );
     const QStandardItem *item       = model->itemFromIndex( srcIndex );
 
-    if( item->data( NameRole ).toString().contains( filterRegExp() ) )
+    if( item->data( NameRole ).toString().contains( filterRegularExpression() ) )
         return true;
 
     if( item->type() == AlbumType )
@@ -211,7 +211,7 @@ AlbumsProxyModel::filterAcceptsRow( int sourceRow, const QModelIndex &sourcePare
         for( int i = 0, count = model->rowCount( srcIndex ); i < count; ++i )
         {
             const QModelIndex &kid = model->index( i, 0, srcIndex );
-            if( kid.data( NameRole ).toString().contains( filterRegExp() ) )
+            if( kid.data( NameRole ).toString().contains( filterRegularExpression() ) )
                 return true;
         }
     }
