@@ -36,6 +36,7 @@ Analyzer::Worker::Worker()
     , m_lastUpdate()
     , m_demoTimer( new QTimer( this ) )
     , m_processTimer( new QTimer( this ) )
+    , m_hibernate( false )
 {
     m_in = (double*) fftw_malloc( m_size * sizeof( double ) );
     m_out = (std::complex<double>*) fftw_malloc( ( m_size / 2 + 1 ) * sizeof( std::complex<double> ) );
@@ -66,11 +67,20 @@ void Analyzer::Worker::stopTimers()
     m_processTimer->stop();
 }
 
-void Analyzer::Worker::receiveData( const QMap<Phonon::AudioDataOutput::Channel, QVector<qint16> > &newData )
+void Analyzer::Worker::setHibernate( bool state )
+{
+    m_hibernate = state;
+    if( m_hibernate )
+        stopTimers();
+    else
+        playbackStateChanged();
+}
+
+void Analyzer::Worker::receiveData( const QMap<int, QVector<qint16> > &newData )
 {
     const int newDataSize = EngineController::DATAOUTPUT_DATA_SIZE;
 
-    if( newData.isEmpty() || newData[Phonon::AudioDataOutput::LeftChannel].size() != newDataSize )
+    if( newData.isEmpty() || newData[0].size() != newDataSize )
         return;
 
     m_rawInMutex.lock();
@@ -79,12 +89,12 @@ void Analyzer::Worker::receiveData( const QMap<Phonon::AudioDataOutput::Channel,
     {
         if( newData.size() == 1 )  // Mono
         {
-            m_rawIn << double( newData[Phonon::AudioDataOutput::LeftChannel][x] );
+            m_rawIn << double( newData[0][x] );
         }
         else     // Anything > Mono is treated as Stereo
         {
-            m_rawIn << ( double( newData[Phonon::AudioDataOutput::LeftChannel][x] )
-            + double( newData[Phonon::AudioDataOutput::RightChannel][x] ) )
+            m_rawIn << ( double( newData[0][x] )
+            + double( newData[1][x] ) )
             / 2; // Average between the channels
         }
         m_rawIn.last() /= ( 1 << 15 ); // Scale to [0, 1]
@@ -370,6 +380,8 @@ void Analyzer::Worker::demo()
 
 void Analyzer::Worker::playbackStateChanged()
 {
+    if( m_hibernate )
+        return;
     bool playing = EngineController::instance()->isPlaying();
     playing ? m_demoTimer->stop() : m_demoTimer->start();
     playing ? m_processTimer->start() : m_processTimer->stop();
