@@ -71,11 +71,7 @@ Q_SIGNALS:
     void refreshRateChanged( qreal );
 
 protected:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    void geometryChanged(const QRectF& newGeometry, const QRectF& oldGeometry) override;
-#else
     void geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry) override;
-#endif
     Analyzer::Worker* createWorker() const override;
     virtual void paletteChange( const QPalette& );
 
