@@ -20,15 +20,15 @@
 #ifndef POPUPDROPPER_H
 #define POPUPDROPPER_H
 
+#include <QAction>
 #include <QGraphicsScene>
-#include <QGraphicsView>
 #include <QStack>
+#include <QSvgRenderer>
+#include <QTimeLine>
 
 #include "PopupDropper_Export.h"
 
 class QMenu;
-class QSvgRenderer;
-class QTimeLine;
 class QWidget;
 class PopupDropper;
 class PopupDropperItem;
