@@ -42,11 +42,7 @@ public:
 
     QSGNode* updatePaintNode( QSGNode * oldNode, UpdatePaintNodeData * updatePaintNodeData ) override;
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    void geometryChanged( const QRectF &newGeometry, const QRectF &oldGeometry ) override;
-#else
     void geometryChange( const QRectF &newGeometry, const QRectF &oldGeometry ) override;
-#endif
 
 Q_SIGNALS:
     void sourceChanged();
