@@ -26,11 +26,11 @@ using namespace Meta;
 AudioCdTrack::AudioCdTrack( Collections::AudioCdCollection *collection, const QString &name, const QUrl &url )
     : Meta::Track()
     , m_collection( collection )
-    , m_artist( 0 )
-    , m_album( 0 )
-    , m_genre( 0 )
-    , m_composer( 0 )
-    , m_year( 0 )
+    , m_artist( nullptr )
+    , m_album( nullptr )
+    , m_genre( nullptr )
+    , m_composer( nullptr )
+    , m_year( nullptr )
     , m_name( name)
     , m_length( 0 )
     , m_trackNumber( 0 )
@@ -286,7 +286,7 @@ AudioCdAlbum::AudioCdAlbum( const QString &name )
     , m_name( name )
     , m_tracks()
     , m_isCompilation( false )
-    , m_albumArtist( 0 )
+    , m_albumArtist( nullptr )
 {
     //nothing to do
 }
