@@ -34,55 +34,55 @@ class AudioCdGenre;
 class AudioCdComposer;
 class AudioCdYear;
 
-typedef KSharedPtr<AudioCdTrack> AudioCdTrackPtr;
-typedef KSharedPtr<AudioCdArtist> AudioCdArtistPtr;
-typedef KSharedPtr<AudioCdAlbum> AudioCdAlbumPtr;
-typedef KSharedPtr<AudioCdGenre> AudioCdGenrePtr;
-typedef KSharedPtr<AudioCdComposer> AudioCdComposerPtr;
-typedef KSharedPtr<AudioCdYear> AudioCdYearPtr;
+typedef AmarokSharedPointer<AudioCdTrack> AudioCdTrackPtr;
+typedef AmarokSharedPointer<AudioCdArtist> AudioCdArtistPtr;
+typedef AmarokSharedPointer<AudioCdAlbum> AudioCdAlbumPtr;
+typedef AmarokSharedPointer<AudioCdGenre> AudioCdGenrePtr;
+typedef AmarokSharedPointer<AudioCdComposer> AudioCdComposerPtr;
+typedef AmarokSharedPointer<AudioCdYear> AudioCdYearPtr;
 
 class AudioCdTrack : public Meta::Track
 {
     public:
-        AudioCdTrack( Collections::AudioCdCollection *collection, const QString &name, const KUrl &url );
-        virtual ~AudioCdTrack();
+        AudioCdTrack( Collections::AudioCdCollection *collection, const QString &name, const QUrl &url );
+        ~AudioCdTrack() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual KUrl playableUrl() const;
-        virtual QString uidUrl() const;
-        virtual QString prettyUrl() const;
-        virtual QString notPlayableReason() const;
+        QUrl playableUrl() const override;
+        QString uidUrl() const override;
+        QString prettyUrl() const override;
+        QString notPlayableReason() const override;
 
-        virtual AlbumPtr album() const;
-        virtual ArtistPtr artist() const;
-        virtual GenrePtr genre() const;
-        virtual ComposerPtr composer() const;
-        virtual YearPtr year() const;
+        AlbumPtr album() const override;
+        ArtistPtr artist() const override;
+        GenrePtr genre() const override;
+        ComposerPtr composer() const override;
+        YearPtr year() const override;
 
         virtual void setTitle( const QString &newTitle );
 
-        virtual qreal bpm() const;
+        qreal bpm() const override;
 
-        virtual QString comment() const;
+        QString comment() const override;
         virtual void setComment ( const QString &newComment );
 
-        virtual qint64 length() const;
+        qint64 length() const override;
 
-        virtual int filesize() const;
-        virtual int sampleRate() const;
-        virtual int bitrate() const;
+        int filesize() const override;
+        int sampleRate() const override;
+        int bitrate() const override;
 
-        virtual int trackNumber() const;
+        int trackNumber() const override;
         virtual void setTrackNumber ( int newTrackNumber );
 
-        virtual int discNumber() const;
+        int discNumber() const override;
         virtual void setDiscNumber ( int newDiscNumber );
 
-        virtual QString type() const;
+        QString type() const override;
 
-        virtual bool inCollection() const;
-        virtual Collections::Collection* collection() const;
+        bool inCollection() const override;
+        Collections::Collection* collection() const override;
 
         //AudioCdTrack specific methods
         void setAlbum( AudioCdAlbumPtr album );
@@ -108,19 +108,19 @@ class AudioCdTrack : public Meta::Track
         QString m_name;
         qint64 m_length;
         int m_trackNumber;
-        KUrl m_playableUrl;
+        QUrl m_playableUrl;
         QString m_fileNameBase;
 };
 
 class AudioCdArtist : public Meta::Artist
 {
     public:
-        AudioCdArtist( const QString &name );
-        virtual ~AudioCdArtist();
+        explicit AudioCdArtist( const QString &name );
+        ~AudioCdArtist() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual TrackList tracks();
+        TrackList tracks() override;
 
         virtual AlbumList albums();
 
@@ -135,23 +135,23 @@ class AudioCdArtist : public Meta::Artist
 class AudioCdAlbum : public Meta::Album
 {
     public:
-        AudioCdAlbum( const QString &name );
-        virtual ~AudioCdAlbum();
+        explicit AudioCdAlbum( const QString &name );
+        ~AudioCdAlbum() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual bool isCompilation() const;
-        virtual bool canUpdateCompilation() const;
-        virtual void setCompilation( bool compilation );
+        bool isCompilation() const override;
+        bool canUpdateCompilation() const override;
+        void setCompilation( bool compilation ) override;
 
-        virtual bool hasAlbumArtist() const;
-        virtual ArtistPtr albumArtist() const;
-        virtual TrackList tracks();
+        bool hasAlbumArtist() const override;
+        ArtistPtr albumArtist() const override;
+        TrackList tracks() override;
 
-        virtual QImage image( int size = 0 ) const;
-        virtual bool hasImage( int size = 0 ) const;
-        virtual bool canUpdateImage() const;
-        virtual void setImage( const QImage &image );
+        QImage image( int size = 0 ) const override;
+        bool hasImage( int size = 0 ) const override;
+        bool canUpdateImage() const override;
+        void setImage( const QImage &image ) override;
 
         //AudioCdAlbum specific methods
         void addTrack( AudioCdTrackPtr track );
@@ -168,12 +168,12 @@ class AudioCdAlbum : public Meta::Album
 class AudioCdGenre : public Meta::Genre
 {
     public:
-        AudioCdGenre( const QString &name );
-        virtual ~AudioCdGenre();
+        explicit AudioCdGenre( const QString &name );
+        ~AudioCdGenre() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual TrackList tracks();
+        TrackList tracks() override;
 
         //AudioCdGenre specific methods
         void addTrack( AudioCdTrackPtr track );
@@ -186,12 +186,12 @@ class AudioCdGenre : public Meta::Genre
 class AudioCdComposer : public Meta::Composer
 {
     public:
-        AudioCdComposer( const QString &name );
-        virtual ~AudioCdComposer();
+        explicit AudioCdComposer( const QString &name );
+        ~AudioCdComposer() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual TrackList tracks();
+        TrackList tracks() override;
 
         //AudioCdComposer specific methods
         void addTrack( AudioCdTrackPtr track );
@@ -204,12 +204,12 @@ class AudioCdComposer : public Meta::Composer
 class AudioCdYear : public Meta::Year
 {
     public:
-        AudioCdYear( const QString &name );
-        virtual ~AudioCdYear();
+        explicit AudioCdYear( const QString &name );
+        ~AudioCdYear() override;
 
-        virtual QString name() const;
+        QString name() const override;
 
-        virtual TrackList tracks();
+        TrackList tracks() override;
 
         //AudioCdYear specific methods
         void addTrack( AudioCdTrackPtr track );
