@@ -197,8 +197,8 @@ SqlTrack::SqlTrack( Collections::SqlCollection *collection, const QStringList &r
     m_playCount = (*(iter++)).toInt();
     m_filetype = Amarok::FileType( (*(iter++)).toInt() );
     m_bpm = (*(iter++)).toFloat();
-    m_createDate = QDateTime::fromSecsSinceEpoch((*(iter++)).toUInt());
-    m_modifyDate = QDateTime::fromSecsSinceEpoch((*(iter++)).toUInt());
+    m_createDate = QDateTime::fromSecsSinceEpoch((*(iter++)).toULongLong());
+    m_modifyDate = QDateTime::fromSecsSinceEpoch((*(iter++)).toULongLong());
 
     // if there is no track gain, we assume a gain of 0
     // if there is no album gain, we use the track gain
@@ -1643,7 +1643,13 @@ SqlAlbum::imageLocation( int size )
     // findCachedImage looks for a scaled version of the fullsize image
     // which may have been saved on a previous lookup
     if( size <= 1 )
-        return QUrl::fromLocalFile( m_imagePath );
+    {
+        QUrl url = QUrl::fromLocalFile( m_imagePath );
+        // don't hand out embedded cover urls that start with file:amarok-sqltrackuid://
+        if( m_imagePath.startsWith( QStringLiteral( "amarok-sqltrackuid" ) ) )
+            url.setScheme( QStringLiteral( "amarok-sqltrackuid" ) );
+        return url;
+    }
 
     QString cachedImagePath = scaledDiskCachePath( size );
 
