@@ -31,35 +31,35 @@ class IpodPlaylistProvider : public Playlists::UserPlaylistProvider, private Pla
     Q_OBJECT
 
     public:
-        IpodPlaylistProvider( IpodCollection *collection );
+        explicit IpodPlaylistProvider( IpodCollection *collection );
         virtual ~IpodPlaylistProvider();
 
         // PlaylistProvider methods:
-        virtual QString prettyName() const;
-        virtual KIcon icon() const;
+        QString prettyName() const override;
+        QIcon icon() const override;
 
-        virtual int playlistCount() const;
-        virtual Playlists::PlaylistList playlists();
+        int playlistCount() const override;
+        Playlists::PlaylistList playlists() override;
 
-        virtual Playlists::PlaylistPtr addPlaylist( Playlists::PlaylistPtr playlist );
-        virtual Meta::TrackPtr addTrack( Meta::TrackPtr track );
+        Playlists::PlaylistPtr addPlaylist(Playlists::PlaylistPtr playlist ) override;
+        Meta::TrackPtr addTrack( const Meta::TrackPtr &track ) override;
 
         // UserPlaylistProvider methods:
-        virtual Playlists::PlaylistPtr save( const Meta::TrackList &tracks,
-                                             const QString& name = QString() );
+        Playlists::PlaylistPtr save( const Meta::TrackList &tracks,
+                                             const QString& name = QString() ) override;
 
-        virtual QActionList providerActions();
-        virtual QActionList playlistActions( const Playlists::PlaylistList &playlists );
-        virtual QActionList trackActions( const QMultiHash<Playlists::PlaylistPtr, int> &playlistTracks );
+        QActionList providerActions() override;
+        QActionList playlistActions( const Playlists::PlaylistList &playlists ) override;
+        QActionList trackActions( const QMultiHash<Playlists::PlaylistPtr, int> &playlistTracks ) override;
 
-        virtual bool isWritable();
-        virtual void renamePlaylist( Playlists::PlaylistPtr playlist, const QString &newName );
-        virtual bool deletePlaylists( const Playlists::PlaylistList &playlistlist );
+        bool isWritable() override;
+        void renamePlaylist( Playlists::PlaylistPtr playlist, const QString &newName ) override;
+        bool deletePlaylists( const Playlists::PlaylistList &playlistlist ) override;
 
         // PlaylistObserver methods:
-        virtual void metadataChanged( Playlists::PlaylistPtr playlist );
-        virtual void trackAdded( Playlists::PlaylistPtr playlist, Meta::TrackPtr track, int position );
-        virtual void trackRemoved( Playlists::PlaylistPtr playlist, int position );
+        void metadataChanged( const Playlists::PlaylistPtr &playlist ) override;
+        void trackAdded( const Playlists::PlaylistPtr &playlist, const Meta::TrackPtr &track, int position ) override;
+        void trackRemoved( const Playlists::PlaylistPtr &playlist, int position ) override;
 
         // IpodPlaylistProvider specific methods:
         /**
@@ -67,7 +67,7 @@ class IpodPlaylistProvider : public Playlists::UserPlaylistProvider, private Pla
          * playlist. The actual call to start copying tracks is deferred to next eventloop
          * iteration to pickup multiple successive addTrack() calls.
          */
-        void scheduleCopyAndInsertToPlaylist( KSharedPtr<IpodPlaylist> playlist );
+        void scheduleCopyAndInsertToPlaylist( AmarokSharedPointer<IpodPlaylist> playlist );
 
         /**
          * Remove this track from all playlists it belongs to, it was removed from the
@@ -80,21 +80,21 @@ class IpodPlaylistProvider : public Playlists::UserPlaylistProvider, private Pla
          */
         bool hasStaleOrOrphaned() const;
 
-    public slots:
+    public Q_SLOTS:
         /**
          * Re-add orphaned files to db and remove stale iTunes database entries. Meant to
          * be connected to the respective QAction.
          */
         void slotConsolidateStaleOrphaned();
 
-    signals:
+    Q_SIGNALS:
         /**
          * Signals to IpodCollection that the database has been dirtied and it has to
          * write the database in some point in time.
          */
         void startWriteDatabaseTimer();
 
-    private slots:
+    private Q_SLOTS:
         void slotCopyAndInsertToPlaylists();
 
     private:
@@ -106,7 +106,7 @@ class IpodPlaylistProvider : public Playlists::UserPlaylistProvider, private Pla
 
         IpodCollection *m_coll;
         Playlists::PlaylistList m_playlists;
-        QSet< KSharedPtr<IpodPlaylist> > m_copyTracksTo;
+        QSet< AmarokSharedPointer<IpodPlaylist> > m_copyTracksTo;
         Playlists::PlaylistPtr m_stalePlaylist;
         Playlists::PlaylistPtr m_orphanedPlaylist;
 };
