@@ -34,7 +34,7 @@ IpodDeviceHelper::parseItdb( const QString &mountPoint, QString &errorMsg )
     GError *error = nullptr;
 
     errorMsg.clear();
-    itdb = itdb_parse( QFile::encodeName( mountPoint ), &error );
+    itdb = itdb_parse( QFile::encodeName( mountPoint ).constData(), &error );
     if( error )
     {
         if( itdb )
@@ -194,7 +194,7 @@ hashAbNeeded( const Itdb_IpodGeneration &generation )
 static bool
 fileFound( const QString &mountPoint, const QString &relFilename )
 {
-    gchar *controlDir = itdb_get_device_dir( QFile::encodeName( mountPoint ) );
+    gchar *controlDir = itdb_get_device_dir( QFile::encodeName( mountPoint ).constData() );
     if( !controlDir )
         return false;
     QString absFilename = QStringLiteral( "%1/%2" ).arg( QFile::decodeName( controlDir ),
@@ -220,7 +220,7 @@ safeToWriteWithMessage( const QString &mountPoint, const Itdb_iTunesDB *itdb, QS
     {
         // okay FireWireGUID may be in plain SysInfo, too, but it's hard to check and
         // error-prone so we just require SysInfoExtended which is machine-generated
-        const QString sysInfoExtended( "SysInfoExtended" );
+        const QString sysInfoExtended( QStringLiteral("SysInfoExtended") );
         bool sysInfoExtendedExists = fileFound( mountPoint, sysInfoExtended );
         message += ( sysInfoExtendedExists )
                    ? i18n( "%1 family uses %2 file to generate correct database checksum.",
@@ -232,7 +232,7 @@ safeToWriteWithMessage( const QString &mountPoint, const Itdb_iTunesDB *itdb, QS
     }
     if( hashInfoNeeded( info->ipod_generation ) )
     {
-        const QString hashInfo( "HashInfo" );
+        const QString hashInfo( QStringLiteral("HashInfo") );
         bool hashInfoExists = fileFound( mountPoint, hashInfo );
         message += hashInfoExists
                    ? i18n( "%1 family uses %2 file to generate correct database checksum.",
@@ -259,7 +259,7 @@ fillInModelComboBox( QComboBox *comboBox, bool someSysInfoFound )
 {
     if( someSysInfoFound )
     {
-        comboBox->addItem( i18n( "Autodetect (%1 file(s) present)", QString( "SysInfo") ), QString() );
+        comboBox->addItem( i18n( "Autodetect (%1 file(s) present)", QStringLiteral( "SysInfo") ), QString() );
         comboBox->setEnabled( false );
         return;
     }
@@ -312,8 +312,8 @@ IpodDeviceHelper::fillInConfigureDialog( QDialog *configureDialog,
     QString warningText;
     QString safeToWriteMessage;
     bool isSafeToWrite = safeToWriteWithMessage( mountPoint, itdb, safeToWriteMessage );
-    bool sysInfoExtendedExists = fileFound( mountPoint, "SysInfoExtended" );
-    bool sysInfoExists = fileFound( mountPoint, "SysInfo" );
+    bool sysInfoExtendedExists = fileFound( mountPoint, QStringLiteral("SysInfoExtended") );
+    bool sysInfoExists = fileFound( mountPoint, QStringLiteral("SysInfo") );
 
     if( itdb )
     {
@@ -326,7 +326,7 @@ IpodDeviceHelper::fillInConfigureDialog( QDialog *configureDialog,
         configureDialogUi->initializeButton->setEnabled( false );
         if( !errorMessage.isEmpty() )
             // to inform user about successful initialization.
-            warningText = QString( "<b>%1</b>" ).arg( errorMessage );
+            warningText = QStringLiteral( "<b>%1</b>" ).arg( errorMessage );
 
         const Itdb_Device *device = itdb->device;
         const Itdb_IpodInfo *info = device ? itdb_device_get_ipod_info( device ) : nullptr;
@@ -345,7 +345,7 @@ IpodDeviceHelper::fillInConfigureDialog( QDialog *configureDialog,
         else
         {
             Q_ASSERT( !safeToWriteMessage.isEmpty() );
-            const QString link( "http://gtkpod.git.sourceforge.net/git/gitweb.cgi?p=gtkpod/libgpod;a=blob_plain;f=README.overview" );
+            const QString link( QStringLiteral("http://gtkpod.git.sourceforge.net/git/gitweb.cgi?p=gtkpod/libgpod;a=blob_plain;f=README.overview") );
             notes += i18nc( "%1 is informational sentence giving reason",
                 "<b>%1</b><br><br>"
                 "As a safety measure, Amarok will <i>refuse to perform any writes</i> to "
@@ -366,7 +366,7 @@ IpodDeviceHelper::fillInConfigureDialog( QDialog *configureDialog,
             fillInModelComboBox( configureDialogUi->modelComboBox, sysInfoExists || sysInfoExtendedExists );
         configureDialogUi->initializeLabel->setEnabled( true );
         configureDialogUi->initializeButton->setEnabled( true );
-        configureDialogUi->initializeButton->setIcon( QIcon::fromTheme( "task-attention" ) );
+        configureDialogUi->initializeButton->setIcon( QIcon::fromTheme( QStringLiteral("task-attention") ) );
         if( !errorMessage.isEmpty() )
             warningText = i18n(
                 "<b>%1</b><br><br>"
@@ -376,7 +376,7 @@ IpodDeviceHelper::fillInConfigureDialog( QDialog *configureDialog,
                 "Initializing iPod <b>destroys iPod track and photo database</b>, however "
                 "it should not delete any tracks. The tracks will become orphaned.",
                 errorMessage,
-                configureDialogUi->initializeButton->text().remove( QChar('&') )
+                configureDialogUi->initializeButton->text().remove( QLatin1Char('&') )
             );
 
         configureDialogUi->infoGroupBox->setEnabled( false );
@@ -420,7 +420,7 @@ IpodDeviceHelper::initializeIpod( const QString &mountPoint,
         const char *modelNumberRaw = modelNumber.constData();
         Itdb_Device *device = itdb_device_new();
         // following call reads existing SysInfo
-        itdb_device_set_mountpoint( device, QFile::encodeName( mountPoint ) );
+        itdb_device_set_mountpoint( device, QFile::encodeName( mountPoint ).constData() );
         const char *field = "ModelNumStr";
         debug() << "Setting SysInfo field" << field << "to value" << modelNumberRaw;
         itdb_device_set_sysinfo( device, field, modelNumberRaw );
@@ -431,7 +431,7 @@ IpodDeviceHelper::initializeIpod( const QString &mountPoint,
             if( error )
             {
                 errorMessage = i18nc( "Do not translate SysInfo",
-                                      "Failed to write SysInfo: %1", error->message );
+                                      "Failed to write SysInfo: %1", QLatin1String(error->message) );
                 g_error_free( error );
             }
             else
@@ -448,8 +448,8 @@ IpodDeviceHelper::initializeIpod( const QString &mountPoint,
         name = ipodName( nullptr ); // return fallback name
 
     GError *error = nullptr;
-    success = itdb_init_ipod( QFile::encodeName( mountPoint ), nullptr /* model number */,
-                              name.toUtf8(), &error );
+    success = itdb_init_ipod( QFile::encodeName( mountPoint ).constData(), nullptr /* model number */,
+                              name.toUtf8().constData(), &error );
     errorMessage.clear();
     if( error )
     {
@@ -471,7 +471,7 @@ IpodDeviceHelper::setIpodName( Itdb_iTunesDB *itdb, const QString &newName )
     if( !mpl )
         return;
     g_free( mpl->name );
-    mpl->name = g_strdup( newName.toUtf8() );
+    mpl->name = g_strdup( newName.toUtf8().constData() );
 }
 
 bool
