@@ -16,7 +16,6 @@
 
 #include "MediaDeviceMeta.h"
 
-#include "SvgHandler.h"
 #include "core/capabilities/ActionsCapability.h"
 #include "core/support/Debug.h"
 #include "core-impl/capabilities/AlbumActionsCapability.h"
@@ -26,11 +25,10 @@
 #include "covermanager/CoverCache.h"
 #include "covermanager/CoverFetchingActions.h"
 
+#include <QAction>
 #include <QIcon>
 #include <QUrl>
 
-#include <QAction>
-
 using namespace Meta;
 
 MediaDeviceTrack::MediaDeviceTrack( Collections::MediaDeviceCollection *collection )
@@ -54,6 +52,7 @@ MediaDeviceTrack::MediaDeviceTrack( Collections::MediaDeviceCollection *collecti
     , m_playCount( 0 )
     , m_rating( 0 )
     , m_bpm( 0 )
+    , m_replayGain( 0 )
     , m_playableUrl()
 {
 }
