@@ -26,7 +26,7 @@
  *
  * Following rules apply when working with capabilities:
  *  * Capabilities get deleted along their media device handler. Therefore use
- *    QWeakPointer everywhere to detect that.
+ *    QPointer everywhere to detect that.
  *  * the one who creates capability using create<Type>() must deleteLater() it when no
  *    longer used.
  */
@@ -35,7 +35,6 @@ namespace Handler
     class MEDIADEVICECOLLECTION_EXPORT Capability : public QObject
     {
         Q_OBJECT
-        Q_ENUMS( Type )
 
         public:
             //add additional capabilities here
@@ -46,6 +45,7 @@ namespace Handler
                         , Artwork = 4 // can read/write artwork
                         , Podcast = 5 // can read/write podcasts
                       };
+            Q_ENUM( Type )
 
             /**
              * @param handler should be set to associated MediaDeviceHandler or Collection.
@@ -53,16 +53,16 @@ namespace Handler
              * The capability sets its parent to handler, so that it can be guaranteed that
              * the handler is valid for Capability's lifetime.
              */
-            Capability( QObject *handler );
-            virtual ~Capability();
+            explicit Capability( QObject *handler );
+            ~Capability() override;
 
-        signals:
+        Q_SIGNALS:
             /**
              * Signals that parent of this object should be set to @param parent
              */
             void signalSetParent( QObject *parent );
 
-        private slots:
+        private Q_SLOTS:
             /**
              * Simply calls setParent( parent ); needed for cases where moveToThread() is
              * called in constructor - setting parent needs to be done in the new thread.
