@@ -24,7 +24,7 @@
 #include "core/collections/QueryMaker.h"
 
 #include <QWeakPointer>
-
+#include <ThreadWeaver/Job>
 
 namespace ThreadWeaver
 {
@@ -44,43 +44,43 @@ class AMAROK_EXPORT MemoryQueryMaker : public QueryMaker
       * @param mc the MemoryCollection instance that the query should be run on.
       * @param collectionId the collectionid that has to be emitted by this querymaker.
       */
-        MemoryQueryMaker( QWeakPointer<MemoryCollection> mc, const QString &collectionId );
-        virtual ~MemoryQueryMaker();
+        MemoryQueryMaker( const QWeakPointer<MemoryCollection> &mc, const QString &collectionId );
+        ~MemoryQueryMaker() override;
 
-        virtual void run();
-        virtual void abortQuery();
+        void run() override;
+        void abortQuery() override;
 
-        virtual QueryMaker* setQueryType( QueryType type );
+        QueryMaker* setQueryType( QueryType type ) override;
 
-        virtual QueryMaker* addReturnValue( qint64 value );
-        virtual QueryMaker* addReturnFunction( ReturnFunction function, qint64 value );
-        virtual QueryMaker* orderBy( qint64 value, bool descending = false );
+        QueryMaker* addReturnValue( qint64 value ) override;
+        QueryMaker* addReturnFunction( ReturnFunction function, qint64 value ) override;
+        QueryMaker* orderBy( qint64 value, bool descending = false ) override;
 
-        virtual QueryMaker* addMatch( const Meta::TrackPtr &track );
-        virtual QueryMaker* addMatch( const Meta::ArtistPtr &artist, ArtistMatchBehaviour behaviour = TrackArtists );
-        virtual QueryMaker* addMatch( const Meta::AlbumPtr &album );
-        virtual QueryMaker* addMatch( const Meta::ComposerPtr &composer );
-        virtual QueryMaker* addMatch( const Meta::GenrePtr &genre );
-        virtual QueryMaker* addMatch( const Meta::YearPtr &year );
-        virtual QueryMaker* addMatch( const Meta::LabelPtr &label );
+        QueryMaker* addMatch( const Meta::TrackPtr &track ) override;
+        QueryMaker* addMatch( const Meta::ArtistPtr &artist, ArtistMatchBehaviour behaviour = TrackArtists ) override;
+        QueryMaker* addMatch( const Meta::AlbumPtr &album ) override;
+        QueryMaker* addMatch( const Meta::ComposerPtr &composer ) override;
+        QueryMaker* addMatch( const Meta::GenrePtr &genre ) override;
+        QueryMaker* addMatch( const Meta::YearPtr &year ) override;
+        QueryMaker* addMatch( const Meta::LabelPtr &label ) override;
 
-        virtual QueryMaker* addFilter( qint64 value, const QString &filter, bool matchBegin, bool matchEnd );
-        virtual QueryMaker* excludeFilter( qint64 value, const QString &filter, bool matchBegin, bool matchEnd );
+        QueryMaker* addFilter( qint64 value, const QString &filter, bool matchBegin, bool matchEnd ) override;
+        QueryMaker* excludeFilter( qint64 value, const QString &filter, bool matchBegin, bool matchEnd ) override;
 
-        virtual QueryMaker* addNumberFilter( qint64 value, qint64 filter, NumberComparison compare );
-        virtual QueryMaker* excludeNumberFilter( qint64 value, qint64 filter, NumberComparison compare );
+        QueryMaker* addNumberFilter( qint64 value, qint64 filter, NumberComparison compare ) override;
+        QueryMaker* excludeNumberFilter( qint64 value, qint64 filter, NumberComparison compare ) override;
 
-        virtual QueryMaker* limitMaxResultSize( int size );
+        QueryMaker* limitMaxResultSize( int size ) override;
 
-        virtual QueryMaker* beginAnd();
-        virtual QueryMaker* beginOr();
-        virtual QueryMaker* endAndOr();
+        QueryMaker* beginAnd() override;
+        QueryMaker* beginOr() override;
+        QueryMaker* endAndOr() override;
 
-        virtual QueryMaker* setAlbumQueryMode( AlbumQueryMode mode );
-        virtual QueryMaker* setLabelQueryMode( LabelQueryMode mode );
+        QueryMaker* setAlbumQueryMode( AlbumQueryMode mode ) override;
+        QueryMaker* setLabelQueryMode( LabelQueryMode mode ) override;
 
-    private slots:
-        void done( ThreadWeaver::Job * job );
+    private Q_SLOTS:
+        void done( ThreadWeaver::JobPointer job );
 
     protected:
 
