@@ -23,8 +23,8 @@
 #include "core-impl/collections/support/MemoryCollection.h"
 
 #include <KDirWatch>
-#include <KIcon>
-
+#include <QIcon>
+#include <QDir>
 #include <solid/device.h>
 
 #include <QtGlobal>
@@ -33,22 +33,23 @@
 class GenericScanManager;
 class UmsPodcastProvider;
 class UmsCollection;
-class UmsCollectionLocation;
 class QAction;
 
 using namespace Collections;
 
 class UmsCollectionFactory : public CollectionFactory
 {
+    Q_PLUGIN_METADATA(IID AmarokPluginFactory_iid FILE "amarok_collection-umscollection.json")
+    Q_INTERFACES(Plugins::PluginFactory)
     Q_OBJECT
 
     public:
-        UmsCollectionFactory( QObject *parent, const QVariantList &args );
-        virtual ~UmsCollectionFactory();
+        UmsCollectionFactory();
+        ~UmsCollectionFactory() override;
 
-        virtual void init();
+        void init() override;
 
-    private slots:
+    private Q_SLOTS:
         /**
          * Called when solid notifier detects a new device has been added
          */
@@ -86,7 +87,7 @@ class UmsCollectionFactory : public CollectionFactory
 
         /**
          * Attempts to create appropriate collection for already identified solid device
-         * @param udi. Should emit newCollection() if the collection was successfully
+         * @param udi. Should Q_EMIT newCollection() if the collection was successfully
          * created and should become visible to the user.
          */
         void createCollectionForSolidDevice( const QString &udi );
@@ -102,41 +103,41 @@ class UmsCollection : public Collection, public Meta::Observer
     public:
         // inherited methods
 
-        UmsCollection( Solid::Device device );
-        virtual ~UmsCollection();
+        explicit UmsCollection( const Solid::Device &device );
+        ~UmsCollection() override;
 
         /* TrackProvider methods */
-        virtual bool possiblyContainsTrack( const KUrl &url ) const;
-        virtual Meta::TrackPtr trackForUrl( const KUrl &url );
+        bool possiblyContainsTrack( const QUrl &url ) const override;
+        Meta::TrackPtr trackForUrl( const QUrl &url ) override;
 
         /* Collection methods */
-        virtual QueryMaker *queryMaker();
-        virtual QString uidUrlProtocol() const;
+        QueryMaker *queryMaker() override;
+        QString uidUrlProtocol() const override;
 
-        virtual QString collectionId() const;
-        virtual QString prettyName() const;
-        virtual KIcon icon() const;
+        QString collectionId() const override;
+        QString prettyName() const override;
+        QIcon icon() const override;
 
-        virtual bool hasCapacity() const;
-        virtual float usedCapacity() const;
-        virtual float totalCapacity() const;
+        bool hasCapacity() const override;
+        float usedCapacity() const override;
+        float totalCapacity() const override;
 
-        virtual CollectionLocation *location();
+        CollectionLocation *location() override;
 
-        virtual bool isOrganizable() const;
+        bool isOrganizable() const override;
 
         /* Capability-related methods */
-        virtual bool hasCapabilityInterface( Capabilities::Capability::Type type ) const;
-        virtual Capabilities::Capability *createCapabilityInterface(
-                Capabilities::Capability::Type type );
+        bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override;
+        Capabilities::Capability *createCapabilityInterface(
+                Capabilities::Capability::Type type ) override;
 
         /* Meta::Observer methods */
-        virtual void metadataChanged( Meta::TrackPtr track );
+        void metadataChanged( const Meta::TrackPtr &track ) override;
         using Meta::Observer::metadataChanged; // silence compiler warning about hidder overloads
 
         /* own methods */
-        const KUrl &musicPath() const { return m_musicPath; }
-        const KUrl &podcastPath() const { return m_podcastPath; }
+        const QUrl &musicUrl() const { return m_musicUrl; }
+        const QUrl &podcastUrl() const { return m_podcastUrl; }
 
         /**
          * Get location where track @param track should be transferred to.
@@ -144,21 +145,21 @@ class UmsCollection : public Collection, public Meta::Observer
          * @param fileExtension new extension to use. Leave empty if you don't wish to
          * change file extension
          */
-        KUrl organizedUrl( Meta::TrackPtr track, const QString &fileExtension = QString() ) const;
+        QUrl organizedUrl( const Meta::TrackPtr &track, const QString &fileExtension = QString() ) const;
 
         QSharedPointer<MemoryCollection> memoryCollection() const { return m_mc; }
 
-    signals:
+    Q_SIGNALS:
         /**
          * Start a count-down that emits updated() signal after it expires.
          * Resets the timer to original timeout if already running. This is to ensure
-         * that we emit update() max. once per <timeout> for batch updates.
+         * that we Q_EMIT update() max. once per \<timeout\> for batch updates.
          *
          * Timers can only be started from "their" thread so use signals & slots for that.
          */
         void startUpdateTimer();
 
-    public slots:
+    public Q_SLOTS:
         /**
          * Destroy the collection (by emitting remove)
          */
@@ -169,12 +170,12 @@ class UmsCollection : public Collection, public Meta::Observer
          */
         void slotEject();
 
-        void slotTrackAdded( KUrl trackLocation );
+        void slotTrackAdded( const QUrl &trackLocation );
         void slotTrackRemoved( const Meta::TrackPtr &track );
 
-    private slots:
+    private Q_SLOTS:
         /**
-         * Update m_lastUpdated timestamp and emit updated()
+         * Update m_lastUpdated timestamp and Q_EMIT updated()
          */
         void collectionUpdated();
 
@@ -185,7 +186,7 @@ class UmsCollection : public Collection, public Meta::Observer
         void slotDirectoryScanned( QSharedPointer<CollectionScanner::Directory> dir );
 
         /**
-         * Starts a timer that ensures we emit updated() signal sometime in future.
+         * Starts a timer that ensures we Q_EMIT updated() signal sometime in future.
          */
         void slotStartUpdateTimer();
 
@@ -214,8 +215,8 @@ class UmsCollection : public Collection, public Meta::Observer
 
         bool m_autoConnect;
         QString m_mountPoint;
-        KUrl m_musicPath;
-        KUrl m_podcastPath;
+        QUrl m_musicUrl;
+        QUrl m_podcastUrl;
         QString m_musicFilenameScheme;
         bool m_vfatSafe;
         bool m_asciiOnly;
