@@ -36,23 +36,23 @@ namespace Meta
         Q_OBJECT
 
         public:
-            MultiTrack( Playlists::PlaylistPtr playlist );
-            ~MultiTrack();
+            explicit MultiTrack( Playlists::PlaylistPtr playlist );
+            ~MultiTrack() override;
 
             QStringList sources() const;
             void setSource( int source );
             int current() const;
-            KUrl nextUrl() const;
+            QUrl nextUrl() const;
 
-            virtual bool hasCapabilityInterface( Capabilities::Capability::Type type ) const;
-            virtual Capabilities::Capability *createCapabilityInterface( Capabilities::Capability::Type type );
+            bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override;
+            Capabilities::Capability *createCapabilityInterface( Capabilities::Capability::Type type ) override;
 
             // forward lots of stuff:
-#define FORWARD( Type, method, default ) Type method() const { return m_currentTrack ? m_currentTrack->method() : default; }
+#define FORWARD( Type, method, default ) Type method() const override { return m_currentTrack ? m_currentTrack->method() : default; }
             FORWARD( QString, name, QString() )
             FORWARD( QString, prettyName, QString() )
-            FORWARD( KUrl, playableUrl, KUrl() )
-            FORWARD( QString, prettyUrl, m_playlist->uidUrl().prettyUrl() )
+            FORWARD( QUrl, playableUrl, QUrl() )
+            FORWARD( QString, prettyUrl, m_playlist->uidUrl().toDisplayString() )
             // TODO: change to m_playlist->uidUrl() unconditionally once playlist restorer can cope with it:
             FORWARD( QString, uidUrl, m_playlist->uidUrl().url() )
             FORWARD( QString, notPlayableReason, i18nc( "Reason why a track is not playable",
@@ -75,18 +75,18 @@ namespace Meta
             FORWARD( QString, type, QString() )
 #undef FORWARD
 
-            void prepareToPlay();
-            virtual StatisticsPtr statistics();
+            void prepareToPlay() override;
+            StatisticsPtr statistics() override;
 
-        signals:
-            void urlChanged( const KUrl &url );
+        Q_SIGNALS:
+            void urlChanged( const QUrl &url );
 
         private:
             using Observer::metadataChanged;
-            virtual void metadataChanged( Meta::TrackPtr track );
+            void metadataChanged( const Meta::TrackPtr &track ) override;
 
             using PlaylistObserver::metadataChanged;
-            virtual void trackAdded( Playlists::PlaylistPtr playlist, TrackPtr track, int position );
+            void trackAdded( const Playlists::PlaylistPtr &playlist, const TrackPtr &track, int position ) override;
 
             /**
              * Implementation for setSource. Must be called with m_lock held for writing.
@@ -98,7 +98,7 @@ namespace Meta
             TrackPtr m_currentTrack;
             /**
              * Guards access to data members; note that m_playlist methods are considered
-             * thread-safe and the pointer itself does not change throughout life of thhis
+             * thread-safe and the pointer itself does not change throughout life of this
              * object, so mere m_playlist->someMethod() doesn't have to be guarded.
              */
             mutable QReadWriteLock m_lock;
