@@ -33,7 +33,7 @@ namespace Playlists
     class PlaylistFile;
     class PlaylistFileLoaderJob;
 
-    typedef KSharedPtr<PlaylistFile> PlaylistFilePtr;
+    typedef AmarokSharedPointer<PlaylistFile> PlaylistFilePtr;
     typedef QList<PlaylistFilePtr> PlaylistFileList;
 
     /**
@@ -45,19 +45,19 @@ namespace Playlists
 
         public:
             /* Playlist methods */
-            virtual KUrl uidUrl() const { return m_url; }
-            virtual QString name() const { return m_url.fileName(); }
-            virtual Meta::TrackList tracks() { return m_tracks; }
-            virtual int trackCount() const;
-            virtual void addTrack( Meta::TrackPtr track, int position );
-            virtual void removeTrack( int position );
-            virtual void triggerTrackLoad();
+            QUrl uidUrl() const override { return m_url; }
+            QString name() const override { return m_url.fileName(); }
+            Meta::TrackList tracks() override { return m_tracks; }
+            int trackCount() const override;
+            void addTrack( const Meta::TrackPtr &track, int position ) override;
+            void removeTrack( int position ) override;
+            void triggerTrackLoad() override;
 
             /**
              * Overrides filename
              */
-            virtual void setName( const QString &name );
-            virtual PlaylistProvider *provider() const { return m_provider; }
+            void setName( const QString &name ) override;
+            PlaylistProvider *provider() const override { return m_provider; }
 
             /* PlaylistFile methods */
             virtual QList<int> queue() { return QList<int>(); }
@@ -75,7 +75,7 @@ namespace Playlists
             virtual bool isWritable() const;
 
             /**
-             * Saves the playlist to underlying file immediatelly.
+             * Saves the playlist to underlying file immediately.
              *
              * @param relative whether to use relative paths to track in the file
              */
@@ -87,11 +87,11 @@ namespace Playlists
              * @note in order to save tracks to file, save method should be called
              **/
             virtual void addTracks( const Meta::TrackList &tracks ) { m_tracks += tracks; }
-            virtual void setGroups( const QStringList &groups ) { m_groups = groups; }
-            virtual QStringList groups() { return m_groups; }
+            void setGroups( const QStringList &groups ) override { m_groups = groups; }
+            QStringList groups() override { return m_groups; }
 
         protected:
-            PlaylistFile( const KUrl &url, PlaylistProvider *provider );
+            PlaylistFile( const QUrl &url, PlaylistProvider *provider );
 
             /**
              * Schedule this playlist file to be saved on the next iteration of the
@@ -130,12 +130,12 @@ namespace Playlists
              * Sets m_relative to true if it ecounters a relative url
              * (this serves to preserve playlist "relativity" across reads & saves)
              **/
-            KUrl getAbsolutePath( const KUrl &url );
+            QUrl getAbsolutePath( const QUrl &url );
 
             PlaylistProvider *m_provider;
             QStringList m_groups;
 
-            KUrl m_url;
+            QUrl m_url;
 
             mutable bool m_tracksLoaded;
             mutable Meta::TrackList m_tracks;
