@@ -62,7 +62,7 @@ MySqlEmbeddedStorage::init( const QString &storageLocation )
 
     QVector<const char*> mysql_args;
     QByteArray dataDir = QStringLiteral( "--datadir=%1" ).arg( databaseDir ).toLocal8Bit();
-    mysql_args << "amarok"
+    mysql_args << databaseName().toUtf8().constData()
                << dataDir.constData()
                // CAUTION: if we ever change the table type we will need to fix a number of MYISAM specific
                // functions, such as FULLTEXT indexing.
@@ -75,8 +75,8 @@ MySqlEmbeddedStorage::init( const QString &storageLocation )
                << "--myisam-recover=FORCE"
 #endif
                << "--key-buffer-size=16777216" // (16Mb)
-               << "--character-set-server=utf8"
-               << "--collation-server=utf8_bin";
+               << "--character-set-server=utf8mb4"
+               << "--collation-server=utf8mb4_bin";
 
 
     if( !QFile::exists( databaseDir ) )
@@ -122,7 +122,7 @@ MySqlEmbeddedStorage::init( const QString &storageLocation )
         return false;
     }
 
-    if( !sharedInit( QLatin1String("amarok") ) )
+    if( !sharedInit( databaseName() ) )
     {
         // if sharedInit fails then we can usually not switch to the correct database
         // sharedInit already reports errors.
