@@ -34,12 +34,12 @@ namespace Capabilities
 
         @author Dan Meltzer <parallelgrapefruit@gmail.com>
     */
-    class AMAROK_CORE_EXPORT StreamInfoCapability : public Capabilities::Capability
+    class AMAROKCORE_EXPORT StreamInfoCapability : public Capabilities::Capability
     {
         Q_OBJECT
         public:
-            StreamInfoCapability() {};
-            virtual ~StreamInfoCapability() {};
+            StreamInfoCapability() {}
+            ~StreamInfoCapability() override {}
 
             /**
              * The human readable name of this stream
