@@ -23,7 +23,6 @@
 #include "core/support/Debug.h"
 
 #include <QTime>
-#include <QChar>
 #include <QFile>
 
 #include <KIO/Global>
@@ -351,7 +350,7 @@ Meta::Field::xesamPrettyToFullFieldName( const QString &name )
     else if( name==Meta::Field::UNIQUEID )
         return XESAM_ID;
     else
-        return "xesamPrettyToFullName: unknown name " + name;
+        return QStringLiteral("xesamPrettyToFullName: unknown name ") + name;
 }
 
 QString
@@ -404,7 +403,7 @@ Meta::Field::xesamFullToPrettyFieldName( const QString &name )
     else if( name == XESAM_ID )
         return Meta::Field::UNIQUEID;
     else
-        return "xesamFullToPrettyName: unknown name " + name;
+        return QStringLiteral("xesamFullToPrettyName: unknown name ") + name;
 }
 
 
@@ -464,7 +463,8 @@ Meta::prettyBitrate( int bitrate )
 {
     //the point here is to force sharing of these strings returned from prettyBitrate()
     static const QString bitrateStore[9] = {
-        "?", "32", "64", "96", "128", "160", "192", "224", "256" };
+        QStringLiteral("?"), QStringLiteral("32"), QStringLiteral("64"), QStringLiteral("96"),
+        QStringLiteral("128"), QStringLiteral("160"), QStringLiteral("192"), QStringLiteral("224"), QStringLiteral("256") };
 
     return (bitrate >=0 && bitrate <= 256 && bitrate % 32 == 0)
                 ? bitrateStore[ bitrate / 32 ]
