@@ -19,11 +19,7 @@
 #include "core/support/Debug.h"
 
 #include <QCryptographicHash>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QNetworkConfigurationManager>
-#else
 #include <QNetworkInformation>
-#endif
 
 #include <KIO/MkdirJob>
 #include <KIO/FileCopyJob>
@@ -114,16 +110,6 @@ PodcastImageFetcher::run()
         Q_EMIT( done( this ) );
         return;
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QNetworkConfigurationManager mgr;
-    if( !mgr.isOnline() )
-    {
-        debug() << "QNetworkConfigurationManager reports we are not online, canceling podcast image download";
-        Q_EMIT( done( this ) );
-        //TODO: schedule another run after Solid reports we are online again
-        return;
-    }
-#else
     if( QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Disconnected )
     {
         debug() << "QNetworkInformation reports we are not online, canceling podcast image download";
@@ -131,7 +117,6 @@ PodcastImageFetcher::run()
         //TODO: schedule another run after Solid reports we are online again
         return;
     }
-#endif
 
     for( Podcasts::PodcastChannelPtr channel : m_channels )
     {
