@@ -32,14 +32,14 @@
 
 using namespace Podcasts;
 
-#define ITUNES_NS  "http://www.itunes.com/dtds/podcast-1.0.dtd"
+#define ITUNES_NS  QStringLiteral("http://www.itunes.com/dtds/podcast-1.0.dtd")
 #define RDF_NS     "http://www.w3.org/1999/02/22-rdf-syntax-ns#"
-#define RSS10_NS   "http://purl.org/rss/1.0/"
-#define RSS20_NS   ""
+#define RSS10_NS   QStringLiteral("http://purl.org/rss/1.0/")
+#define RSS20_NS   QStringLiteral("")
 #define ATOM_NS    "http://www.w3.org/2005/Atom"
 #define ENC_NS     "http://purl.oclc.org/net/rss_2.0/enc#"
-#define CONTENT_NS "http://purl.org/rss/1.0/modules/content"
-#define DC_NS      "http://purl.org/dc/elements/1.1/"
+#define CONTENT_NS QStringLiteral("http://purl.org/rss/1.0/modules/content")
+#define DC_NS      QStringLiteral("http://purl.org/dc/elements/1.1/")
 
 // regular expressions for linkification:
 #define RE_USER   "[-+_%\\.\\w]+"
@@ -86,10 +86,10 @@ PodcastReader::Action::characters( PodcastReader *podcastReader ) const
 
 // initialization of the feed parser automata:
 PodcastReader::StaticData::StaticData()
-        : removeScripts( QStringLiteral("<script[^<]*</script>|<script[^>]*>"), Qt::CaseInsensitive )
-        , mightBeHtml( "<\\?xml[^>]*\\?>|<br[^>]*>|<p[^>]*>|&lt;|&gt;|&amp;|&quot;|"
-                       "<([-:\\w\\d]+)[^>]*(/>|>.*</\\1>)|<hr[>]*>|&#\\d+;|&#x[a-fA-F\\d]+;", Qt::CaseInsensitive )
-        , linkify( "\\b(" RE_URL ")|\\b(" RE_MAIL ")|(\n)" )
+        : removeScripts( QStringLiteral("<script[^<]*</script>|<script[^>]*>"), QRegularExpression::CaseInsensitiveOption )
+        , mightBeHtml( QStringLiteral("<\\?xml[^>]*\\?>|<br[^>]*>|<p[^>]*>|&lt;|&gt;|&amp;|&quot;|"
+                       "<([-:\\w\\d]+)[^>]*(/>|>.*</\\1>)|<hr[>]*>|&#\\d+;|&#x[a-fA-F\\d]+;"), QRegularExpression::CaseInsensitiveOption )
+        , linkify( QStringLiteral("\\b(" RE_URL ")|\\b(" RE_MAIL ")|(\n)") )
 
         , startAction( rootMap )
 
@@ -418,7 +418,7 @@ PodcastReader::~PodcastReader()
 bool
 PodcastReader::mightBeHtml( const QString& text ) //Static
 {
-    return sd.mightBeHtml.indexIn( text ) != -1;
+    return text.indexOf( sd.mightBeHtml ) != -1;
 }
 
 bool PodcastReader::read( QIODevice *device )
@@ -577,7 +577,7 @@ PodcastReader::elementType() const
             break;
 
         case Content:
-            if( m_xmlReader.namespaceUri() == ATOM_NS &&
+            if( m_xmlReader.namespaceUri() == QStringLiteral( ATOM_NS ) &&
                     // ignore atom:content elements that do not
                     // have content but only refer to some url:
                     !hasAttribute( ATOM_NS, "src" ) )
@@ -589,9 +589,9 @@ PodcastReader::elementType() const
                 //    http://tools.ietf.org/html/rfc4287#section-4.1.3
                 if( hasAttribute( ATOM_NS, "type" ) )
                 {
-                    QStringRef type( attribute( ATOM_NS, "type" ) );
+                    QStringView type( attribute( ATOM_NS, "type" ) );
 
-                    if( type == "text" || type == "html" || type == "xhtml" )
+                    if( type == QStringLiteral("text") || type == QStringLiteral("html") || type == QStringLiteral("xhtml") )
                     {
                         elementType = SupportedContent;
                     }
@@ -786,7 +786,7 @@ PodcastReader::unescape( const QString &text )
     {
         QChar c( text[ i ] );
 
-        if( c == '&' )
+        if( c == QLatin1Char( '&' ) )
         {
             int endIndex = text.indexOf( QLatin1Char(';'), i );
 
@@ -795,11 +795,11 @@ PodcastReader::unescape( const QString &text )
                 // fix invalid input
                 buf += c;
             }
-            else if( text[ i + 1 ] == '#' )
+            else if( text[ i + 1 ] == QLatin1Char( '#' ) )
             {
                 int num = 0;
                 bool ok = false;
-                if( text[ i + 2 ] == 'x' )
+                if( text[ i + 2 ] == QLatin1Char( 'x' ) )
                 {
                     QString entity( text.mid( i + 3, endIndex - i - 3 ) );
                     num = entity.toInt( &ok, 16 );
@@ -916,12 +916,12 @@ QString
 PodcastReader::textToHtml( const QString &text )
 {
     QString buf;
-    QRegExp re( sd.linkify );
+    QRegularExpression re( sd.linkify );
     int index = 0;
 
     for(;;)
     {
-        int next = re.indexIn( text, index );
+        int next = text.indexOf( re, index );
 
         if( next == -1 )
             break;
@@ -932,8 +932,9 @@ PodcastReader::textToHtml( const QString &text )
         }
 
         QString s;
+        QRegularExpressionMatch rmatch = re.match( text, index );
 
-        if( !(s = re.cap( 1 )).isEmpty() )
+        if( !(s = rmatch.captured( 1 )).isEmpty() )
         {
             if( s.startsWith( QLatin1String( "javascript:" ), Qt::CaseInsensitive ) ||
                 s.startsWith( QLatin1String( "exec:" ), Qt::CaseInsensitive ) )
@@ -946,17 +947,17 @@ PodcastReader::textToHtml( const QString &text )
                     .arg( s.toHtmlEscaped() );
             }
         }
-        else if( !(s = re.cap( 2 )).isEmpty() )
+        else if( !(s = rmatch.captured( 2 )).isEmpty() )
         {
             buf += QStringLiteral( "<a href=\"mailto:%1\">%1</a>" )
                 .arg( s.toHtmlEscaped() );
         }
-        else if( !re.cap( 3 ).isEmpty() )
+        else if( !rmatch.captured( 3 ).isEmpty() )
         {
             buf += QLatin1String("<br/>\n");
         }
 
-        index = re.pos() + re.matchedLength();
+        index = text.indexOf( re, index ) + rmatch.capturedLength();
     }
 
     buf += text.mid( index ).toHtmlEscaped();
@@ -1005,7 +1006,7 @@ PodcastReader::beginUnknownFeedType()
 void
 PodcastReader::beginRss()
 {
-    if( m_xmlReader.attributes().value( QStringLiteral("version") ) != "2.0" )
+    if( m_xmlReader.attributes().value( QStringLiteral("version") ) != QStringLiteral( "2.0" ) )
     {
         // TODO: change this string once we support more
         stopWithError( i18n( "%1 is not an RSS version 2.0 feed.", m_url.url() ) );
@@ -1016,7 +1017,7 @@ void
 PodcastReader::beginRdf()
 {
     bool ok = true;
-    if( m_xmlReader.namespaceUri() != RDF_NS )
+    if( m_xmlReader.namespaceUri() != QStringLiteral( RDF_NS ) )
     {
         ok = false;
     }
@@ -1024,7 +1025,7 @@ PodcastReader::beginRdf()
     if( ok )
     {
         bool found = false;
-        foreach( const QXmlStreamNamespaceDeclaration &nsdecl, m_xmlReader.namespaceDeclarations() )
+        for( const QXmlStreamNamespaceDeclaration &nsdecl : m_xmlReader.namespaceDeclarations() )
         {
             if( nsdecl.namespaceUri() == RSS10_NS )
             {
@@ -1044,7 +1045,7 @@ PodcastReader::beginRdf()
 void
 PodcastReader::beginFeed()
 {
-    if( m_xmlReader.namespaceUri() != ATOM_NS )
+    if( m_xmlReader.namespaceUri() != QStringLiteral( ATOM_NS ) )
     {
         stopWithError( i18n( "%1 is not a valid Atom feed.", m_url.url() ) );
     }
@@ -1132,7 +1133,7 @@ PodcastReader::endItem()
             description += i18n( "Alternative Enclosures:" );
             description += QLatin1String("</b><br/>\n<ul>");
 
-            foreach( const Enclosure& enclosure, m_enclosures )
+            for( const Enclosure& enclosure : m_enclosures )
             {
                 description += QStringLiteral( "<li><a href=\"%1\">%2</a> (%3, %4)</li>" )
                                .arg( enclosure.url().url().toHtmlEscaped(),
@@ -1203,7 +1204,7 @@ PodcastReader::beginEnclosure()
     // See:
     //    http://www.rssboard.org/rss-specification
     //    http://www.xs4all.nl/~foz/mod_enclosure.html
-    QStringRef str;
+    QStringView str;
 
     str = m_xmlReader.attributes().value( QStringLiteral("url") );
 
@@ -1276,7 +1277,7 @@ PodcastReader::endKeywords()
 {
     QList<QString> keywords( m_current->keywords() );
 
-    foreach( const QString &keyword, m_buffer.split( QLatin1Char(',') ) )
+    for( const QString &keyword : m_buffer.split( QLatin1Char(',') ) )
     {
         QString kwd( keyword.simplified() );
         if( !kwd.isEmpty() && !keywords.contains( kwd ) )
@@ -1322,17 +1323,17 @@ PodcastReader::endCreator()
 void
 PodcastReader::beginXml()
 {
-    m_buffer += '<';
+    m_buffer += QLatin1Char( '<' );
     m_buffer += m_xmlReader.name().toString();
 
-    foreach( const QXmlStreamAttribute &attr, m_xmlReader.attributes() )
+    for( const QXmlStreamAttribute &attr : m_xmlReader.attributes() )
     {
         m_buffer += QStringLiteral( " %1=\"%2\"" )
                     .arg( attr.name().toString(),
                           attr.value().toString().toHtmlEscaped() );
     }
 
-    m_buffer += '>';
+    m_buffer += QLatin1Char( '>' );
 }
 
 void
@@ -1348,17 +1349,17 @@ PodcastReader::beginAtomText()
 {
     if( hasAttribute( ATOM_NS, "type" ) )
     {
-        QStringRef type( attribute( ATOM_NS, "type" ) );
+        QStringView type( attribute( ATOM_NS, "type" ) );
 
-        if( type == "text" )
+        if( type == QStringLiteral("text") )
         {
             m_contentType = TextContent;
         }
-        else if( type == "html" )
+        else if( type == QStringLiteral("html") )
         {
             m_contentType = HtmlContent;
         }
-        else if( type == "xhtml" )
+        else if( type == QStringLiteral("xhtml") )
         {
             m_contentType = XHtmlContent;
         }
@@ -1440,11 +1441,11 @@ void
 PodcastReader::beginAtomFeedLink()
 {
     if( !hasAttribute( ATOM_NS, "rel" ) ||
-            attribute( ATOM_NS, "rel" ) == "alternate" )
+            attribute( ATOM_NS, "rel" ) == QStringLiteral("alternate") )
     {
         m_channel->setWebLink( QUrl( attribute( ATOM_NS, "href" ).toString() ) );
     }
-    else if( attribute( ATOM_NS, "rel" ) == "self" )
+    else if( attribute( ATOM_NS, "rel" ) == QStringLiteral("self") )
     {
         m_url = QUrl( attribute( ATOM_NS, "href" ).toString() );
 
@@ -1459,7 +1460,7 @@ PodcastReader::beginAtomFeedLink()
 void
 PodcastReader::beginAtomEntryLink()
 {
-    if( attribute( ATOM_NS, "rel" ) == "enclosure" )
+    if( attribute( ATOM_NS, "rel" ) == QStringLiteral("enclosure") )
     {
         QUrl url( attribute( ATOM_NS, "href" ).toString() );
         int filesize = 0;
@@ -1563,7 +1564,7 @@ PodcastReader::endXml()
 {
     m_buffer += QLatin1String("</");
     m_buffer += m_xmlReader.name().toString();
-    m_buffer += '>';
+    m_buffer += QLatin1Char('>');
 }
 
 void
@@ -1578,26 +1579,26 @@ PodcastReader::readEscapedCharacters()
     m_buffer += m_xmlReader.text().toString().toHtmlEscaped() ;
 }
 
-QStringRef
+QStringView
 PodcastReader::attribute( const char *namespaceUri, const char *name ) const
 {
     // workaround, because Qt seems to have a bug:
     // when the default namespace is used attributes
     // aren't inside this namespace for some reason
-    if( m_xmlReader.attributes().hasAttribute( namespaceUri, name ) )
-        return m_xmlReader.attributes().value( namespaceUri, name );
+    if( m_xmlReader.attributes().hasAttribute( QLatin1String(namespaceUri), QLatin1String(name) ) )
+        return m_xmlReader.attributes().value( QLatin1String(namespaceUri), QLatin1String(name) );
     else
-        return m_xmlReader.attributes().value( QString(), name );
+        return m_xmlReader.attributes().value( QString(), QLatin1String(name) );
 }
 
 bool
 PodcastReader::hasAttribute( const char *namespaceUri, const char *name ) const
 {
     // see PodcastReader::attribute()
-    if( m_xmlReader.attributes().hasAttribute( namespaceUri, name ) )
+    if( m_xmlReader.attributes().hasAttribute( QLatin1String(namespaceUri), QLatin1String(name) ) )
         return true;
     else
-        return m_xmlReader.attributes().hasAttribute( QString(), name );
+        return m_xmlReader.attributes().hasAttribute( QString(), QLatin1String(name) );
 }
 
 QDateTime
@@ -1607,17 +1608,19 @@ PodcastReader::parsePubDate( const QString &dateString )
     QString parseInput = dateString;
     debug() << "Parsing pubdate: " << parseInput;
 
-    QRegExp rfcDateDayRegex( QStringLiteral("^[A-Z]{1}[a-z]{2}\\s*,\\s*(.*)") );
-    if( rfcDateDayRegex.indexIn( parseInput ) != -1 )
+    QRegularExpression rfcDateDayRegex( QStringLiteral("^[A-Z]{1}[a-z]{2}\\s*,\\s*(.*)") );
+    QRegularExpressionMatch dateMatch = rfcDateDayRegex.match( parseInput );
+    if( dateMatch.hasMatch() )
     {
-        parseInput = rfcDateDayRegex.cap(1);
+        parseInput = dateMatch.captured(1);
     }
     //Hack around a to strict RFCDate implementation in KDateTime.
     //See https://bugs.kde.org/show_bug.cgi?id=231062
-    QRegExp rfcMonthLowercase( QStringLiteral("^\\d+\\s+\\b(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)\\b") );
-    if( rfcMonthLowercase.indexIn( parseInput ) != -1 )
+    QRegularExpression rfcMonthLowercase( QStringLiteral("^\\d+\\s+\\b(jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec)\\b") );
+    QRegularExpressionMatch monthMatch = rfcDateDayRegex.match( parseInput );
+    if( monthMatch.hasMatch() )
     {
-        QString lowerMonth = rfcMonthLowercase.cap( 1 );
+        QString lowerMonth = monthMatch.captured( 1 );
         QString upperMonth = lowerMonth;
         upperMonth.replace( 0, 1, lowerMonth.at( 0 ).toUpper() );
         parseInput.replace( lowerMonth, upperMonth );
@@ -1663,7 +1666,7 @@ PodcastReader::podcastEpisodeCheck( Podcasts::PodcastEpisodePtr episode )
 //     debug() << "episode url: " << episode->prettyUrl();
 //     debug() << "episode guid: " << episode->guid();
 
-    foreach( PodcastEpisodePtr match, episodes )
+    for( PodcastEpisodePtr match : episodes )
     {
 //         debug() << "match title: " << match->title();
 //         debug() << "match url: " << match->prettyUrl();
