@@ -20,13 +20,14 @@
 
 #include "Debug.h"
 
+#include <QIODevice>
 #include <QString>
 
 class IndentPrivate
     : public QObject
 {
 private:
-    explicit IndentPrivate(QObject* parent = 0);
+    explicit IndentPrivate(QObject* parent = nullptr);
 
 public:
     static IndentPrivate* instance();
@@ -34,4 +35,29 @@ public:
     QString m_string;
 };
 
+class NoDebugStream : public QIODevice
+{
+public:
+    NoDebugStream()
+    {
+        open(WriteOnly);
+    }
+    bool isSequential() const override
+    {
+        return true;
+    }
+    qint64 readData(char *, qint64) override
+    {
+        return 0;
+    }
+    qint64 readLineData(char *, qint64) override
+    {
+        return 0;
+    }
+    qint64 writeData(const char *, qint64 len) override
+    {
+        return len;
+    }
+};
+
 #endif // DEBUGPRIVATE_H
