@@ -94,7 +94,7 @@ VorbisFormat::ffmpegParameters( const Configuration &configuration ) const
     for( const Property &property : m_propertyList )
     {
         if( !configuration.property( property.name() ).isNull()
-            && configuration.property( property.name() ).type() == property.variantType() )
+            && configuration.property( property.name() ).typeId() == property.metaType() )
         {
             if( property.name() == "quality" )
             {
