@@ -24,24 +24,6 @@
 class KAboutData;
 class QPlainTextEdit;
 
-struct BackendDescriptor {
-    explicit BackendDescriptor(const QString &path = QString());
-
-    bool isValid;
-
-    QString iid;
-
-    QString name;
-    QString version;
-    QString website;
-    int preference;
-
-    QString pluginPath;
-
-    /** Implemented for qSort(QList) */
-    bool operator <(const BackendDescriptor &rhs) const;
-};
-
 class AMAROK_EXPORT DiagnosticDialog : public QDialog
 {
     Q_OBJECT
@@ -53,7 +35,6 @@ private:
     QPlainTextEdit *m_textBox;
 
     const QString generateReport( const KAboutData *aboutData );
-    const BackendDescriptor getPreferredBackend() const;
 
 private Q_SLOTS:
     void slotCopyToClipboard() const;
