@@ -37,7 +37,6 @@ class QXmlStreamWriter;
 
 namespace Collections {
     class Collection;
-    class QueryMaker;
 }
 
 namespace Dynamic
@@ -63,13 +62,13 @@ namespace Dynamic
 
         public:
             AbstractBias();
-            virtual ~AbstractBias();
+            ~AbstractBias() override;
 
-            /** Reads the contensts of this object from an xml stream */
+            /** Reads the contents of this object from an xml stream */
             virtual void fromXml( QXmlStreamReader *reader );
 
             /** Writes the contents of this object to an xml stream.
-                Only the content is writen and no enclosing tags.
+                Only the content is written and no enclosing tags.
                 This is done to make it mirror the constructor which does not read those
                 tags either.
             */
@@ -95,7 +94,7 @@ namespace Dynamic
 
             /** Create a widget appropriate for editing the bias.
             */
-            virtual QWidget* widget( QWidget* parent = 0 );
+            virtual QWidget* widget( QWidget* parent = nullptr );
 
             /** Paints an operator (like "and" or a progress bar") in front of a bias item */
             virtual void paintOperator( QPainter* painter, const QRect &rect, Dynamic::AbstractBias* bias );
@@ -107,12 +106,12 @@ namespace Dynamic
                 the result was received or invalidate called.
                 @param playlist The current playlist context for the track.
                 @param contextCount The number of songs that are already fixed.
-                @parem finalCount The number of tracks that the playlist should finally contain (including the contextCount)
+                @param finalCount The number of tracks that the playlist should finally contain (including the contextCount)
                 @param universe A TrackCollectionPtr to be used for the resulting TrackSet
             */
             virtual TrackSet matchingTracks( const Meta::TrackList& playlist,
                                              int contextCount, int finalCount,
-                                             const TrackCollectionPtr universe ) const = 0;
+                                             const TrackCollectionPtr &universe ) const = 0;
 
             /** Returns true if indicated track fits that position.
                 The function might block until a result is ready.
@@ -121,12 +120,11 @@ namespace Dynamic
                                 if we search a track for the end of the playlist.
                 @param playlist The current playlist context for the track.
                 @param contextCount The number of songs that are already fixed.
-                @param universe A TrackCollectionPtr to be used for the resulting TrackSet
             */
             virtual bool trackMatches( int position,
                                        const Meta::TrackList& playlist, int contextCount ) const = 0;
 
-        signals:
+        Q_SIGNALS:
             /** This signal is emitted when the bias is changed.
                 e.g. an internal variable is set so that the bias will return different tracks.
                 this can also happen if the bias depends on the current track and this
@@ -140,7 +138,7 @@ namespace Dynamic
             /** Emitted when the result to a previously called matchingTracks is ready */
             void resultReady( const Dynamic::TrackSet &set );
 
-        public slots:
+        public Q_SLOTS:
             /** This slot is called when the bias should discard cached results.
                 This will be done in case a new playlist is requested for an updated
                 collection.
@@ -149,9 +147,9 @@ namespace Dynamic
 
             /** Call this function when this bias should be replaced by a new one.
                 @param newBias The bias that replaces this bias. If you give
-                an empty BiasPrt as argument the bias will be removed.
+                an empty BiasPtr as argument the bias will be removed.
             */
-            virtual void replace( Dynamic::BiasPtr newBias );
+            virtual void replace( const Dynamic::BiasPtr &newBias );
     };
 
     /** A bias that returns all the tracks in the universe as possible tracks */
@@ -161,21 +159,21 @@ namespace Dynamic
 
         public:
             RandomBias();
-            virtual ~RandomBias();
+            ~RandomBias() override;
 
             static QString sName();
-            virtual QString name() const;
-            virtual QString toString() const;
+            QString name() const override;
+            QString toString() const override;
 
-            virtual QWidget* widget( QWidget* parent = 0 );
+            QWidget* widget( QWidget* parent = nullptr ) override;
 
-            virtual TrackSet matchingTracks( const Meta::TrackList& playlist,
+            TrackSet matchingTracks( const Meta::TrackList& playlist,
                                              int contextCount, int finalCount,
-                                             const TrackCollectionPtr universe ) const;
+                                             const TrackCollectionPtr &universe ) const override;
 
-            virtual bool trackMatches( int position,
+            bool trackMatches( int position,
                                        const Meta::TrackList& playlist,
-                                       int contextCount ) const;
+                                       int contextCount ) const override;
 
         private:
             Q_DISABLE_COPY(RandomBias)
@@ -192,50 +190,49 @@ namespace Dynamic
 
         public:
             /** Create a new And bias.
-                @param empty If true, then the newly created bias will not have a set of example sub-biases.
             */
             AndBias();
-            virtual ~AndBias();
+            ~AndBias() override;
 
-            virtual void fromXml( QXmlStreamReader *reader );
-            virtual void toXml( QXmlStreamWriter *writer ) const;
+            void fromXml( QXmlStreamReader *reader ) override;
+            void toXml( QXmlStreamWriter *writer ) const override;
 
             static QString sName();
-            virtual QString name() const;
-            virtual QString toString() const;
+            QString name() const override;
+            QString toString() const override;
 
-            virtual QWidget* widget( QWidget* parent = 0 );
-            virtual void paintOperator( QPainter* painter, const QRect &rect, Dynamic::AbstractBias* bias );
+            QWidget* widget( QWidget* parent = nullptr ) override;
+            void paintOperator( QPainter* painter, const QRect &rect, Dynamic::AbstractBias* bias ) override;
 
-            virtual TrackSet matchingTracks( const Meta::TrackList& playlist,
+            TrackSet matchingTracks( const Meta::TrackList& playlist,
                                              int contextCount, int finalCount,
-                                             const TrackCollectionPtr universe ) const;
+                                             const TrackCollectionPtr &universe ) const override;
 
-            virtual bool trackMatches( int position,
+            bool trackMatches( int position,
                                        const Meta::TrackList& playlist,
-                                       int contextCount ) const;
+                                       int contextCount ) const override;
 
             /** Appends a bias to this bias.
                 This object will take ownership of the bias and free it when destroyed.
             */
-            virtual void appendBias( Dynamic::BiasPtr bias );
+            virtual void appendBias( const Dynamic::BiasPtr &bias );
             virtual void moveBias( int from, int to );
 
             BiasList biases() const
             { return m_biases; }
 
-        signals:
+        Q_SIGNALS:
             void biasAppended( Dynamic::BiasPtr bias );
             void biasRemoved( int pos );
             void biasMoved( int from, int to );
 
-        public slots:
-            virtual void invalidate();
+        public Q_SLOTS:
+            void invalidate() override;
 
-        protected slots:
+        protected Q_SLOTS:
             virtual void resultReceived( const Dynamic::TrackSet &tracks );
-            virtual void biasReplaced( Dynamic::BiasPtr oldBias, Dynamic::BiasPtr newBias );
-            virtual void biasChanged( Dynamic::BiasPtr bias );
+            virtual void biasReplaced( const Dynamic::BiasPtr &oldBias, const Dynamic::BiasPtr &newBias );
+            virtual void biasChanged( const Dynamic::BiasPtr &bias );
 
         protected:
             BiasList m_biases;
@@ -255,21 +252,21 @@ namespace Dynamic
             OrBias();
 
             static QString sName();
-            virtual QString name() const;
-            virtual QString toString() const;
+            QString name() const override;
+            QString toString() const override;
 
-            virtual void paintOperator( QPainter* painter, const QRect &rect, Dynamic::AbstractBias* bias );
+            void paintOperator( QPainter* painter, const QRect &rect, Dynamic::AbstractBias* bias ) override;
 
-            virtual TrackSet matchingTracks( const Meta::TrackList& playlist,
+            TrackSet matchingTracks( const Meta::TrackList& playlist,
                                              int contextCount, int finalCount,
-                                             const TrackCollectionPtr universe ) const;
+                                             const TrackCollectionPtr &universe ) const override;
 
-            virtual bool trackMatches( int position,
+            bool trackMatches( int position,
                                        const Meta::TrackList& playlist,
-                                       int contextCount ) const;
+                                       int contextCount ) const override;
 
-        protected slots:
-            virtual void resultReceived( const Dynamic::TrackSet &tracks );
+        protected Q_SLOTS:
+            void resultReceived( const Dynamic::TrackSet &tracks ) override;
 
         private:
             Q_DISABLE_COPY(OrBias)
