@@ -27,7 +27,6 @@
 #include <KLocalizedString>
 
 #include <QComboBox>
-#include <QFormLayout>
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
@@ -63,8 +62,8 @@ Dynamic::AlbumPlayBias::fromXml( QXmlStreamReader *reader )
 
         if( reader->isStartElement() )
         {
-            QStringRef name = reader->name();
-            if( name == "follow" )
+            QStringView name = reader->name();
+            if( name == QStringLiteral("follow") )
                 m_follow = followForName( reader->readElementText(QXmlStreamReader::SkipChildElements) );
             else
             {
