@@ -24,7 +24,7 @@
 #include <QImage>
 
 #include "core/support/Debug.h"
-#include "core/meta/Meta.h"
+#include "core/meta/forward_declarations.h"
 #include "EngineController.h"
     
  // NOTE if not on mac, this whole file is useless, so not even going to try
@@ -35,7 +35,7 @@ class GrowlInterface : QObject
     public:
         GrowlInterface( QString appName );
 
-    protected slots:
+    protected Q_SLOTS:
         void show( Meta::TrackPtr );
 
     private:
