@@ -35,13 +35,8 @@ class NetworkAccessViewer;
 #endif // DEBUG_BUILD_TYPE
 
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <KIO/AccessManager>
-typedef KIO::Integration::AccessManager NetworkAccessManagerProxyBase;
-#else
 #include <QNetworkAccessManager>
 typedef QNetworkAccessManager NetworkAccessManagerProxyBase;
-#endif
 
 namespace The
 {
