@@ -21,8 +21,7 @@
 #include "PlaylistBreadcrumbItemSortButton.h"
 #include "PlaylistBreadcrumbLevel.h"
 #include "PlaylistDefines.h"
-
-#include <KHBox>
+#include "widgets/BoxWidget.h"
 
 #include <QMenu>
 #include <QStringList>
@@ -44,26 +43,26 @@ public:
      * @param currentColumn The column corresponding to the current sort level
      * @param parent The parent QWidget
      */
-    explicit BreadcrumbItemMenu( Column currentColumn, QWidget *parent = 0 );
+    explicit BreadcrumbItemMenu( Column currentColumn, QWidget *parent = nullptr );
 
     /**
      * Destructor.
      */
-    virtual ~BreadcrumbItemMenu();
+    ~BreadcrumbItemMenu() override;
 
-signals:
+Q_SIGNALS:
     /**
      * Emitted when a non-Shuffle item is triggered from the menu.
-     * @param action the action in the menu that has been triggered.
+     * @param internalColName the internal name of the column in which the menu has been triggered.
      */
     void actionClicked( QString internalColName );
 
     /**
-     * Emmited when the Shuffle item is triggered from the menu.
+     * Emitted when the Shuffle item is triggered from the menu.
      */
     void shuffleActionClicked();
 
-private slots:
+private Q_SLOTS:
     /**
      * Handles the selection of an item from the menu.
      * @param action the action in the menu that has been triggered.
@@ -75,7 +74,7 @@ private slots:
  *  A single item that represents a level of a general-purpose breadcrumb ribbon.
  *  @author Téo Mrnjavac <teo@kde.org>
  */
-class BreadcrumbItem : public KHBox
+class BreadcrumbItem : public BoxWidget
 {
     Q_OBJECT
 
@@ -85,12 +84,12 @@ public:
      * @param level The BreadcrumbLevel assigned to this item.
      * @param parent The parent QWidget.
      */
-    explicit BreadcrumbItem( BreadcrumbLevel *level, QWidget *parent = 0 );
+    explicit BreadcrumbItem( BreadcrumbLevel *level, QWidget *parent = nullptr );
 
     /**
      * Destructor.
      */
-    ~BreadcrumbItem();
+    ~BreadcrumbItem() override;
 
     /**
      * Returns the internal name of this item.
@@ -121,7 +120,7 @@ public:
      */
     const BreadcrumbItemMenu *menu();
 
-signals:
+Q_SIGNALS:
     /**
      * Emitted when the item has been clicked.
      */
@@ -132,7 +131,7 @@ signals:
      */
     void orderInverted();
 
-protected slots:
+protected Q_SLOTS:
     void updateSizePolicy();
 
 private:
@@ -155,12 +154,12 @@ public:
     /**
      * Constructor.
      */
-    BreadcrumbAddMenuButton( QWidget *parent );
+    explicit BreadcrumbAddMenuButton( QWidget *parent );
 
     /**
      * Destructor.
      */
-    virtual ~BreadcrumbAddMenuButton();
+    ~BreadcrumbAddMenuButton() override;
 
     /**
      * Menu accessor for the purpose of connecting to menu's signals.
