@@ -90,7 +90,7 @@ ViewUrlRunner::prettyCommand() const
 QIcon
 ViewUrlRunner::icon() const
 {
-    return QIcon( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/playlist-bookmark-16.png") ) ) );
+    return QIcon::fromTheme( QStringLiteral("bookmarks-bookmarked") );
 }
 
 } //namespace Playlist
