@@ -33,7 +33,7 @@ LayoutConfigAction::LayoutConfigAction( QWidget * parent )
     : QAction( parent )
     , m_layoutDialog( nullptr )
 {
-    QIcon actionIcon( QPixmap( QStandardPaths::locate( QStandardPaths::GenericDataLocation, QStringLiteral("amarok/images/playlist-layouts-22.png")) ) );    //TEMPORARY ICON
+    QIcon actionIcon = QIcon::fromTheme( QStringLiteral("view-media-playlist-amarok") );
     setIcon( actionIcon );
     m_layoutMenu = new QMenu( parent );
     setMenu( m_layoutMenu );
