@@ -123,7 +123,7 @@ class LayoutItemConfigRowElement
 };
 
 /**
- * This class corrosponds to a  row in a playlist layout
+ * This class corresponds to a  row in a playlist layout
  * @author Nikolaj Hald Nielsen <nhn@kde.org>
  */
 class LayoutItemConfigRow
@@ -134,7 +134,7 @@ class LayoutItemConfigRow
          * Add an element to the end of this row.
          * @param element The element to add.
          */
-        void addElement( LayoutItemConfigRowElement element );
+        void addElement(const LayoutItemConfigRowElement &element );
 
         /**
          * Get the number of elements in this row.
@@ -200,7 +200,7 @@ class LayoutItemConfig
          * Add a row to this config.
          * @param row The row to add.
          */
-        void addRow( LayoutItemConfigRow row );
+        void addRow( const LayoutItemConfigRow &row );
 
         /**
          * Set whether the cover image should be shown or not.
@@ -273,7 +273,7 @@ class PlaylistLayout
         /**
          * Set the layout config for the specified part type.
          */
-        void setLayoutForPart( Part part, LayoutItemConfig itemConfig );
+        void setLayoutForPart( Part part, const LayoutItemConfig &itemConfig );
 
         /**
          * Set whether this config can be edited by the user.
