@@ -20,9 +20,10 @@
 #include "core/support/Debug.h"
 #include "playlist/PlaylistActions.h"
 
-#include <QMenu>
 #include <KLocalizedString>
-#include <QStandardPaths>
+
+#include <QActionGroup>
+#include <QMenu>
 
 NavigatorConfigAction::NavigatorConfigAction( QWidget * parent )
     : QAction( parent )
