@@ -17,10 +17,10 @@
 #ifndef NAVIGATORCONFIGACTION_H
 #define NAVIGATORCONFIGACTION_H
 
-#include <KAction>
+#include <QAction>
 
 
-class NavigatorConfigAction : public KAction
+class NavigatorConfigAction : public QAction
 {
     Q_OBJECT
 public:
@@ -29,18 +29,18 @@ public:
     * Constructor.
     * @param parent Parent widget.
     */
-    NavigatorConfigAction( QWidget * parent );
+    explicit NavigatorConfigAction( QWidget * parent );
 
     /**
     * Destructor.
     */
-    ~NavigatorConfigAction();
+    ~NavigatorConfigAction() override;
 
-protected slots:
+protected Q_SLOTS:
 
     /**
     * Set the currently active navigator based on the selected action.
-    * @param layoutAction The action triggered.
+    * @param navigatorAction The action triggered.
     */
     void setActiveNavigator( QAction *navigatorAction );
 
