@@ -44,7 +44,6 @@
 
 #include <KColorScheme>
 #include <KRatingPainter>  // #include <KratingPainter> does not work on some distros
-#include <KWindowSystem>
 
 #include <QAction>
 #include <QFontMetricsF>
@@ -806,7 +805,7 @@ void Playlist::PrettyItemDelegate::setModelData( QWidget * editor, QAbstractItem
 
     QList<int> columns = changeMap.keys();
 
-    foreach( int column, columns )
+    for( int column : columns )
     {
         QString value = changeMap.value( column );
 
@@ -843,11 +842,12 @@ void Playlist::PrettyItemDelegate::setModelData( QWidget * editor, QAbstractItem
                     debug() << "parse TitleWithTrackNum";
                     //we need to parse out the track number and the track name (and check
                     //if the string is even valid...)
-                    //QRegExp rx("(\\d+)\\s-\\s(.*))");
-                    QRegExp rx("(\\d+)(\\s-\\s)(.*)");
-                    if ( rx.indexIn( value ) != -1) {
-                        int trackNumber = rx.cap( 1 ).toInt();
-                        QString trackName = rx.cap( 3 );
+                    //QRegularExpression rx("(\\d+)\\s-\\s(.*))");
+                    QRegularExpression rx(QStringLiteral("(\\d+)(\\s-\\s)(.*)"));
+                    QRegularExpressionMatch rmatch = rx.match( value );
+                    if ( rmatch.hasMatch() ) {
+                        int trackNumber = rmatch.captured( 1 ).toInt();
+                        QString trackName = rmatch.captured( 3 );
                         debug() << "split TitleWithTrackNum into " << trackNumber << " and " << trackName;
                         ec->setTrackNumber( trackNumber );
                         ec->setTitle( trackName );
@@ -929,13 +929,13 @@ Playlist::PrettyItemDelegate::buildTrackArgsMap( const Meta::TrackPtr &track ) c
     args[QStringLiteral("initial")] = albumartist.mid( 0, 1 ).toUpper();    //artists starting with The are already handled above
     args[QStringLiteral("filetype")] = track->type();
 
-    args[QStringLiteral("rating")] = track->statistics()->rating();
-    args[QStringLiteral("filesize")] = track->filesize();
-    args[QStringLiteral("length")] = track->length() / 1000;
+    args[QStringLiteral("rating")] = QString::number( track->statistics()->rating() );
+    args[QStringLiteral("filesize")] = QString::number( track->filesize() );
+    args[QStringLiteral("length")] = QString::number( track->length() / 1000 );
 
     if ( track->trackNumber() )
     {
-        QString trackNum = QStringLiteral( "%1" ).arg( track->trackNumber(), 2, 10, QChar('0') );
+        QString trackNum = QStringLiteral( "%1" ).arg( track->trackNumber(), 2, 10, QLatin1Char('0') );
         args[QStringLiteral("track")] = trackNum;
     }
 
