@@ -117,7 +117,7 @@ ConstraintGroup::toXml( QDomDocument& doc, QDomElement& elem ) const
         }
     }
 
-    foreach( ConstraintNode* child, m_children ) {
+    for( ConstraintNode* child : m_children ) {
         child->toXml( doc, group );
     }
 
@@ -136,7 +136,7 @@ ConstraintGroup::initQueryMaker( Collections::QueryMaker* qm ) const
             return qm;
         }
 
-        foreach( ConstraintNode* child, m_children ) {
+        for( ConstraintNode* child : m_children ) {
             child->initQueryMaker( qm );
         }
 
@@ -187,7 +187,7 @@ ConstraintGroup::satisfaction( const Meta::TrackList& l ) const
     }
 
     // remove the independent constraints from the hash
-    foreach( int key, constraintMatchTypes.uniqueKeys() ) {
+    for( int key : constraintMatchTypes.uniqueKeys() ) {
         QList<int> vals = constraintMatchTypes.values( key );
         if ( vals.size() <= 1 ) {
             constraintMatchTypes.remove( key );
@@ -202,7 +202,7 @@ ConstraintGroup::suggestPlaylistSize() const
 {
     quint32 s = 0;
     quint32 c = 0;
-    foreach( ConstraintNode* child, m_children ) {
+    for( ConstraintNode* child : m_children ) {
         quint32 x = child->suggestPlaylistSize();
         if ( x > 0 ) {
             s += x;
@@ -221,7 +221,7 @@ ConstraintGroup::combineInterdependentConstraints( const Meta::TrackList& l, con
 {
     /* Handle interdependent constraints properly.
      * See constraints/Matching.h for a description of why this is necessary. */
-    foreach( int key, cmt.uniqueKeys() ) {
+    for( int key : cmt.uniqueKeys() ) {
         QList<int> vals = cmt.values( key );
         // set up the blank matching array
         QBitArray m;
@@ -232,7 +232,7 @@ ConstraintGroup::combineInterdependentConstraints( const Meta::TrackList& l, con
         }
 
         // combine the arrays from the appropriate constraints
-        foreach( int v, vals ) {
+        for( int v : vals ) {
             ConstraintTypes::MatchingConstraint* cge = dynamic_cast<ConstraintTypes::MatchingConstraint*>( m_children[v] );
             if ( m_matchtype == MatchAny ) {
                 m |= cge->whatTracksMatch( l );
