@@ -1,5 +1,5 @@
 /****************************************************************************************
- * Copyright (c) 2008-2011 Soren Harward <stharward@gmail.com>                          *
+ * Copyright (c) 2008-2012 Soren Harward <stharward@gmail.com>                          *
  *                                                                                      *
  * This program is free software; you can redistribute it and/or modify it under        *
  * the terms of the GNU General Public License as published by the Free Software        *
@@ -21,7 +21,7 @@
 
 #include "playlistgenerator/Constraint.h"
 
-#include "core/meta/Meta.h"
+#include "core/meta/forward_declarations.h"
 
 #include <QPointer>
 #include <QString>
@@ -44,17 +44,15 @@ namespace ConstraintTypes {
             static Constraint* createNew(ConstraintNode*);
             static ConstraintFactoryEntry* registerMe();
 
-            virtual QWidget* editWidget() const;
-            virtual void toXml(QDomDocument&, QDomElement&) const;
+            QWidget* editWidget() const override;
+            void toXml(QDomDocument&, QDomElement&) const override;
 
-            virtual QString getName() const;
+            QString getName() const override;
 
-            virtual double satisfaction( const Meta::TrackList& ) const;
-            virtual quint32 suggestInitialPlaylistSize() const;
+            double satisfaction( const Meta::TrackList& ) const override;
+            quint32 suggestPlaylistSize() const override;
 
-            virtual void audit( const Meta::TrackList& ) const;
-
-        private slots:
+        private Q_SLOTS:
             void setPosition( const int );
             void setStrictness( const int );
             void setCheckpoint( const Meta::DataPtr& );
@@ -67,8 +65,8 @@ namespace ConstraintTypes {
             class AlbumMatcher;
 
             Checkpoint( QDomElement&, ConstraintNode* );
-            Checkpoint( ConstraintNode* );
-            ~Checkpoint();
+            explicit Checkpoint( ConstraintNode* );
+            ~Checkpoint() override;
 
             // constraint parameters
             qint64 m_position;
@@ -89,7 +87,7 @@ namespace ConstraintTypes {
         
         public:
             AbstractMatcher() {}
-            virtual ~AbstractMatcher() {}
+            ~AbstractMatcher() override {}
 
             virtual QList<int> find( const Meta::TrackList& ) const = 0;
             virtual bool match( const Meta::TrackPtr& ) const = 0;
@@ -99,10 +97,10 @@ namespace ConstraintTypes {
     class Checkpoint::TrackMatcher : public AbstractMatcher {
         public:
             TrackMatcher( const Meta::TrackPtr& );
-            virtual ~TrackMatcher() {}
+            ~TrackMatcher() override;
 
-            virtual QList<int> find( const Meta::TrackList& ) const;
-            virtual bool match( const Meta::TrackPtr& ) const;
+            QList<int> find( const Meta::TrackList& ) const override;
+            bool match( const Meta::TrackPtr& ) const override;
 
         private:
             Meta::TrackPtr m_trackToMatch;
@@ -112,10 +110,10 @@ namespace ConstraintTypes {
     class Checkpoint::AlbumMatcher : public AbstractMatcher {
         public:
             AlbumMatcher( const Meta::AlbumPtr& );
-            virtual ~AlbumMatcher() {}
+            ~AlbumMatcher() override;
 
-            virtual QList<int> find( const Meta::TrackList& ) const;
-            virtual bool match( const Meta::TrackPtr& ) const;
+            QList<int> find( const Meta::TrackList& ) const override;
+            bool match( const Meta::TrackPtr& ) const override;
 
         private:
             Meta::AlbumPtr m_albumToMatch;
@@ -125,10 +123,10 @@ namespace ConstraintTypes {
     class Checkpoint::ArtistMatcher : public AbstractMatcher {
         public:
             ArtistMatcher( const Meta::ArtistPtr& );
-            virtual ~ArtistMatcher() {}
+            ~ArtistMatcher() override;
 
-            virtual QList<int> find( const Meta::TrackList& ) const;
-            virtual bool match( const Meta::TrackPtr& ) const;
+            QList<int> find( const Meta::TrackList& ) const override;
+            bool match( const Meta::TrackPtr& ) const override;
 
         private:
             Meta::ArtistPtr m_artistToMatch;
@@ -140,14 +138,14 @@ namespace ConstraintTypes {
         public:
             CheckpointEditWidget( const qint64, const int, const Meta::DataPtr& );
 
-        signals:
+        Q_SIGNALS:
             void updated();
             void nameChanged( const QString& );
             void positionChanged( const int );
             void strictnessChanged( const int );
             void checkpointChanged( const Meta::DataPtr& );
 
-        private slots:
+        private Q_SLOTS:
             void on_timeEdit_Position_timeChanged( const QTime& );
             void on_slider_Strictness_valueChanged( const int );
             void on_trackSelector_selectionChanged( const Meta::DataPtr& );
