@@ -41,22 +41,22 @@ namespace ConstraintTypes {
             static Constraint* createNew( ConstraintNode* );
             static ConstraintFactoryEntry* registerMe();
 
-            virtual QWidget* editWidget() const;
-            virtual void toXml( QDomDocument&, QDomElement& ) const;
+            QWidget* editWidget() const override;
+            void toXml( QDomDocument&, QDomElement& ) const override;
 
-            virtual QString getName() const;
+            QString getName() const override;
 
-            virtual double satisfaction( const Meta::TrackList& ) const;
-            virtual quint32 suggestPlaylistSize() const;
+            double satisfaction( const Meta::TrackList& ) const override;
+            quint32 suggestPlaylistSize() const override;
 
-        private slots:
+        private Q_SLOTS:
             void setComparison( const int );
             void setLength( const int );
             void setStrictness( const int );
 
         private:
             PlaylistLength( QDomElement&, ConstraintNode* );
-            PlaylistLength( ConstraintNode* );
+            explicit PlaylistLength( ConstraintNode* );
 
             // constraint parameters
             quint32 m_length;
@@ -73,13 +73,13 @@ namespace ConstraintTypes {
         public:
             PlaylistLengthEditWidget( const int, const int, const int );
 
-        signals:
+        Q_SIGNALS:
             void updated();
             void lengthChanged( const int );
             void comparisonChanged( const int );
             void strictnessChanged( const int );
 
-        private slots:
+        private Q_SLOTS:
             void on_spinBox_Length_valueChanged( const int );
             void on_comboBox_Comparison_currentIndexChanged( const int );
             void on_slider_Strictness_valueChanged( const int );
