@@ -40,19 +40,19 @@ namespace ConstraintTypes {
             static Constraint* createNew( ConstraintNode* );
             static ConstraintFactoryEntry* registerMe();
 
-            virtual QWidget* editWidget() const;
-            virtual void toXml( QDomDocument&, QDomElement& ) const;
+            QWidget* editWidget() const override;
+            void toXml( QDomDocument&, QDomElement& ) const override;
 
-            virtual QString getName() const;
+            QString getName() const override;
             
-            virtual double satisfaction( const Meta::TrackList& ) const;
+            double satisfaction( const Meta::TrackList& ) const override;
 
-        private slots:
+        private Q_SLOTS:
             void setField( const int );
 
         private:
             PreventDuplicates( QDomElement&, ConstraintNode* );
-            PreventDuplicates( ConstraintNode* );
+            explicit PreventDuplicates( ConstraintNode* );
 
             double penalty( const int ) const;
 
@@ -64,13 +64,13 @@ namespace ConstraintTypes {
         Q_OBJECT
 
         public:
-            PreventDuplicatesEditWidget( const int );
+            explicit PreventDuplicatesEditWidget( const int );
 
-        signals:
+        Q_SIGNALS:
             void updated();
             void fieldChanged( const int );
 
-        private slots:
+        private Q_SLOTS:
             void on_comboBox_Field_currentIndexChanged( const int );
 
         private:
