@@ -82,7 +82,7 @@ ConstraintTypes::TagMatch::TagMatch( QDomElement& xmlelem, ConstraintNode* p )
             m_value = a.value().toInt();
         } else if ( m_fieldsModel->type_of( m_field ) == FieldTypeDate ) {
             if ( m_comparison == CompareDateWithin ) {
-                QStringList parts = a.value().split(' ');
+                QStringList parts = a.value().split(QLatin1Char(' '));
                 if ( parts.size() == 2 ) {
                     int u = parts.at( 0 ).toInt();
                     int v = 0;
@@ -305,7 +305,8 @@ double
 ConstraintTypes::TagMatch::satisfaction( const Meta::TrackList& tl ) const
 {
     double satisfaction = 0.0;
-    foreach( Meta::TrackPtr t, tl ) {
+    for( Meta::TrackPtr t : tl )
+    {
         if ( matches( t ) ) {
             satisfaction += 1.0;
         }
@@ -496,9 +497,8 @@ void
 ConstraintTypes::TagMatch::setInvert( bool v )
 {
     if ( m_invert != v ) {
-        foreach( const Meta::TrackPtr t, m_matchCache.keys() ) {
+        for( const Meta::TrackPtr &t : m_matchCache.keys() )
             m_matchCache.insert( t, !m_matchCache.value( t ) );
-        }
     }
     m_invert = v;
     Q_EMIT dataChanged();
