@@ -81,7 +81,7 @@ SqlPlaylistGroup::save()
         QString query = QStringLiteral("INSERT INTO playlist_groups ( parent_id, name, \
                 description) VALUES ( %1, '%2', '%3' );");
         query = query.arg( QString::number( parentId ), m_name, m_description );
-        m_dbId = sqlStorage->insert( query, nullptr );
+        m_dbId = sqlStorage->insert( query, QString() );
     }
 }
 
@@ -207,7 +207,8 @@ SqlPlaylistGroup::allChildGroups() const
 {
     SqlPlaylistGroupList groups;
     groups << childSqlGroups();
-    foreach( SqlPlaylistGroupPtr childGroup, groups )
+    const auto cg = groups;
+    for( const SqlPlaylistGroupPtr &childGroup : cg )
     {
         groups << childGroup->allChildGroups();
     }
@@ -219,7 +220,7 @@ SqlPlaylistGroup::allChildPlaylists() const
 {
     SqlPlaylistList playlists;
     playlists << childSqlPlaylists();
-    foreach( SqlPlaylistGroupPtr childGroup, childSqlGroups() )
+    for( SqlPlaylistGroupPtr childGroup : childSqlGroups() )
     {
         playlists << childGroup->allChildPlaylists();
     }
