@@ -17,70 +17,71 @@
 #ifndef AMAROK_COLLECTION_SQLUSERPLAYLISTPROVIDER_H
 #define AMAROK_COLLECTION_SQLUSERPLAYLISTPROVIDER_H
 
-#include "playlistmanager/UserPlaylistProvider.h"
+#include "core-impl/playlists/providers/user/UserPlaylistProvider.h"
 #include "SqlPlaylist.h"
 #include "SqlPlaylistGroup.h"
 
-#include <klocale.h>
-#include <kicon.h>
+#include <QIcon>
 
-class QAction;
+#include <KLocalizedString>
+
+
+namespace Playlists {
 
 class AMAROK_EXPORT SqlUserPlaylistProvider : public UserPlaylistProvider
 {
     Q_OBJECT
     public:
-        SqlUserPlaylistProvider();
-        ~SqlUserPlaylistProvider();
+        /**
+         * SqlUserPlaylistProvider constructor
+         * @param debug used for unit testing; enabling means skipping
+         * confirmation dialogs when deleting or renaming playlists.
+         */
+        explicit SqlUserPlaylistProvider( bool debug = false );
+        ~SqlUserPlaylistProvider() override;
 
         /* PlaylistProvider functions */
-        virtual QString prettyName() const { return i18n( "Internal Database" ); }
+        QString prettyName() const override { return i18n( "Amarok Database" ); }
         virtual QString description() const { return i18n( "Local playlists stored in the database" ); }
-        virtual KIcon icon() const { return KIcon( "server-database" ); }
+        QIcon icon() const override { return QIcon::fromTheme( QStringLiteral("server-database") ); }
 
-        virtual Meta::PlaylistList playlists();
+        int playlistCount() const override;
+        Playlists::PlaylistList playlists() override;
 
-        virtual bool canSavePlaylists() { return true; }
-        virtual Meta::PlaylistPtr save( const Meta::TrackList &tracks );
-        virtual Meta::PlaylistPtr save( const Meta::TrackList &tracks, const QString& name );
-
-        virtual bool supportsEmptyGroups() { return true; }
-
-        QList<QAction *> playlistActions( Meta::PlaylistPtr playlist );
-        QList<QAction *> trackActions( Meta::PlaylistPtr playlist,
-                                                  int trackIndex );
+        virtual Playlists::PlaylistPtr save( const Meta::TrackList &tracks );
+        Playlists::PlaylistPtr save( const Meta::TrackList &tracks, const QString& name ) override;
 
         /* UserPlaylistProvider functions */
-        virtual void deletePlaylists( Meta::PlaylistList playlistlist );
+        bool isWritable() override;
+        bool deletePlaylists( const Playlists::PlaylistList &playlistlist ) override;
+        void renamePlaylist(Playlists::PlaylistPtr playlist, const QString &newName ) override;
 
-        Meta::SqlPlaylistGroupPtr group( const QString &name );
-        bool import( const QString& fromLocation );
+        Playlists::SqlPlaylistGroupPtr group( const QString &name );
 
-        static Meta::SqlPlaylistList toSqlPlaylists( Meta::PlaylistList playlists );
-
-    signals:
-        void updated();
-
-    private slots:
-        void slotDelete();
-        void slotRename();
-        void slotRemove();
+        static Playlists::SqlPlaylistList toSqlPlaylists( Playlists::PlaylistList playlists );
 
     private:
         void reloadFromDb();
-        Meta::SqlPlaylistGroupPtr m_root;
+        Playlists::SqlPlaylistGroupPtr m_root;
 
         void createTables();
         void deleteTables();
         void checkTables();
+        /**
+         * removes COLUMN "description" from "playlists"
+         */
+        void upgradeVersion2to3();
         void loadFromDb();
 
-        Meta::SqlPlaylistList selectedPlaylists() const
+        bool deleteSqlPlaylists( Playlists::SqlPlaylistList playlistlist );
+
+        Playlists::SqlPlaylistList selectedPlaylists() const
             { return m_selectedPlaylists; }
-        Meta::SqlPlaylistList m_selectedPlaylists;
-        QAction *m_renameAction;
-        QAction *m_deleteAction;
-        QAction *m_removeTrackAction;
+        Playlists::SqlPlaylistList m_selectedPlaylists;
+
+        const bool m_debug;
 };
 
+} //namespace Playlists
+
 #endif
