@@ -60,12 +60,15 @@ class ScriptListDockWidget;
             void closeEvent( QCloseEvent *event ) override;
             ScriptConsoleItem* createScriptItem( const QString &script );
             ScriptListDockWidget *getScriptListDockWidget();
+            bool loadScripts();
 
             QPointer<ScriptConsoleItem> m_scriptItem;
             QDockWidget *m_consoleWidget;
             QDockWidget *m_codeWidget;
             QDockWidget *m_outputWidget;
             QDockWidget *m_errorWidget;
+            QAction *m_startAction;
+            QAction *m_stopAction;
             QString m_savePath;
             KTextEditor::Editor *m_editor;
             ScriptListDockWidget *m_scriptListDock;
