@@ -35,8 +35,8 @@ namespace ScriptConsoleNS
         Q_OBJECT
 
         public:
-            ScriptConsoleItem( QObject *parent, const QString &name, const QString &path
-                            , const QString &category, ScriptEditorDocument *document );
+            ScriptConsoleItem( QObject *parent, const QString &name, const QString &category
+                            , const QString &path, ScriptEditorDocument *document );
             ~ScriptConsoleItem() override;
             ScriptEditorDocument* document() { return m_viewFactory; }
             bool start( bool silent = false ) override;
@@ -67,7 +67,7 @@ namespace ScriptConsoleNS
 
             void timerEvent(QTimerEvent* event) override;
             void initializeScriptEngine() override;
-            static KPluginInfo createSpecFile( const QString &name, const QString &category, const QString &path );
+            static KPluginMetaData createSpecFile( const QString &name, const QString &category, const QString &path );
             QString handleError( QJSValue *result ) override;
 
     };
