@@ -36,7 +36,7 @@ namespace AmarokScript
         Q_OBJECT
 
         public:
-            AmarokPlaylistScript( AmarokScriptEngine *engine );
+            explicit AmarokPlaylistScript( AmarokScriptEngine *engine );
 
             /**
              * Return the index of the currently playing track in the playlist.
@@ -61,7 +61,7 @@ namespace AmarokScript
             /**
              * Append @param track to playlist.
              */
-            Q_INVOKABLE void addTrack( Meta::TrackPtr track );
+            Q_INVOKABLE void addTrack( const Meta::TrackPtr &track );
 
             /**
              * Load the list of tracks represented by the urls and append to playlist.
@@ -84,14 +84,14 @@ namespace AmarokScript
             Q_INVOKABLE void playByIndex( int index );
 
             /**
-             * Prepend the the track represented by the passed url and start playing it.
+             * Prepend the track represented by the passed url and start playing it.
              */
             Q_INVOKABLE void playMedia( const QUrl &url );
 
             /**
              * Prepend @param track and start playing it.
              */
-            Q_INVOKABLE void playTrack( Meta::TrackPtr track );
+            Q_INVOKABLE void playTrack( const Meta::TrackPtr &track );
 
             /**
              * Prepend the tracks represented by the passed urls and start playing them.
@@ -114,12 +114,16 @@ namespace AmarokScript
             Q_INVOKABLE void removeByIndex( int index );
 
             /**
-             * Save the current playlist at the absolute path @param path.
+             * Save the current playlist at the absolute path @p path.
+             *
+             * @param path the absolute path.
              */
             Q_INVOKABLE void savePlaylist( const QString& path );
 
             /**
              * Set whether to stop playing after the current track.
+             *
+             * @param on @c true if on, @c false otherwise.
              */
             Q_INVOKABLE void setStopAfterCurrent( bool on );
 
@@ -153,7 +157,7 @@ namespace AmarokScript
              */
             Q_INVOKABLE QStringList selectedFilenames();
 
-        signals:
+        Q_SIGNALS:
             /**
              * Emitted when tracks are added to the playlist.
              */
@@ -164,7 +168,7 @@ namespace AmarokScript
              */
             void trackRemoved( int start, int end );
 
-        private slots:
+        private Q_SLOTS:
             void slotTrackInserted( const QModelIndex&, int start, int end );
             void slotTrackRemoved( const QModelIndex&, int start, int end );
 
@@ -173,6 +177,4 @@ namespace AmarokScript
     };
 }
 
-Q_DECLARE_METATYPE( QList<QUrl> )
-
 #endif
