@@ -26,7 +26,6 @@
 #include "widgets/SearchWidget.h"
 #include "widgets/BoxWidget.h"
 
-#include <QLabel>
 #include <QLayout>
 #include <QMenuBar>
 
@@ -53,7 +52,7 @@ ServiceFactory::trackForUrl( const QUrl &url )
         init();
     }
 
-    foreach( ServiceBase *service, m_activeServices )
+    for( ServiceBase *service : m_activeServices )
     {
         if( !service->serviceReady() )
         {
@@ -77,6 +76,7 @@ ServiceFactory::trackForUrl( const QUrl &url )
 void ServiceFactory::clearActiveServices()
 {
     m_activeServices.clear();
+    m_initialized = false;
 }
 
 void ServiceFactory::slotServiceReady()
@@ -150,7 +150,7 @@ ServiceBase::ServiceBase( const QString &name, ServiceFactory *parent, bool useC
     m_bottomPanel->setFrameStyle( QFrame::NoFrame );
     m_bottomPanel->setLineWidth(2);
     m_bottomPanel->layout()->setSpacing( 2 );
-    m_bottomPanel->layout()->setMargin( 2 );
+    m_bottomPanel->layout()->setContentsMargins( 2, 2, 2, 2 );
 
     m_filterModel = new QSortFilterProxyModel( this );
     m_filterModel->setSortCaseSensitivity( Qt::CaseInsensitive );
