@@ -23,8 +23,6 @@
 #include "core/support/Debug.h"
 #include "services/ServiceBase.h"
 
-#include <KService>
-
 #include <QSet>
 #include <QCoreApplication>
 
@@ -80,9 +78,12 @@ ServicePluginManager::setFactories( const QList<QSharedPointer<Plugins::PluginFa
         if( !factory )
             continue;
 
-        foreach( ServiceBase * service, factory->activeServices() )
+        for( ServiceBase * service : factory->activeServices() )
             ServiceBrowser::instance()->removeCategory( service );
         factory->clearActiveServices();
+
+        disconnect( factory.data(), &ServiceFactory::newService, this, &ServicePluginManager::slotNewService );
+        disconnect( factory.data(), &ServiceFactory::removeService, this, &ServicePluginManager::slotRemoveService );
     }
 
     // create new factories
@@ -125,7 +126,7 @@ ServicePluginManager::loadedServices() const
         if( !factory )
             continue;
 
-        foreach( ServiceBase *service, factory->activeServices() )
+        for( ServiceBase *service : factory->activeServices() )
             names << service->name();
     }
     return names;
