@@ -26,17 +26,19 @@ class AmpacheAccountLogin;
 
 class AmpacheServiceFactory: public ServiceFactory
 {
+    Q_PLUGIN_METADATA(IID AmarokPluginFactory_iid FILE "amarok_service_ampache.json")
+    Q_INTERFACES(Plugins::PluginFactory)
     Q_OBJECT
 
     public:
-        AmpacheServiceFactory( QObject *parent, const QVariantList &args );
-        virtual ~AmpacheServiceFactory() {}
+        AmpacheServiceFactory();
+        ~AmpacheServiceFactory() override {}
 
-        virtual bool possiblyContainsTrack( const KUrl &url ) const;
+        bool possiblyContainsTrack( const QUrl &url ) const override;
 
-        virtual void init();
-        virtual QString name();
-        virtual KConfigGroup config();
+        void init() override;
+        QString name() override;
+        KConfigGroup config() override;
 };
 
 
@@ -52,17 +54,17 @@ Q_OBJECT
     
 public:
     explicit AmpacheService( AmpacheServiceFactory* parent, const QString &name,
-                             const QString &url = QString(), const QString &username = QString(),
+                             const QUrl &url = QUrl(), const QString &username = QString(),
                              const QString &password = QString() );
 
-    ~AmpacheService();
+    ~AmpacheService() override;
 
-    void polish();
+    void polish() override;
     void reauthenticate();
 
-    virtual Collections::Collection * collection() { return m_collection; }
+    Collections::Collection * collection() override { return m_collection; }
 
-private slots:
+private Q_SLOTS:
     void onLoginSuccessful();
 
 private:
