@@ -215,7 +215,7 @@ JamendoXmlParser::readConfigFile( const QString &filename )
         m_reader.readNext();
         if( m_reader.isStartElement() )
         {
-            QStringRef localname = m_reader.name();
+            QStringView localname = m_reader.name();
             if( localname == "artist" )
             {
                 readArtist();
@@ -258,7 +258,7 @@ JamendoXmlParser::readArtist()
             break;
         if( m_reader.isStartElement() )
         {
-            QStringRef localname = m_reader.name();
+            QStringView localname = m_reader.name();
             if( localname == "id" )
                 m_currentArtistId = m_reader.readElementText().toInt();
             else if ( localname == "name" )
@@ -317,7 +317,7 @@ JamendoXmlParser::readAlbum()
             break;
         if( m_reader.isStartElement() )
         {
-            QStringRef localname = m_reader.name();
+            QStringView localname = m_reader.name();
 
             if( localname == "id" )
                 m_currentAlbumId = m_reader.readElementText().toInt();
@@ -334,7 +334,7 @@ JamendoXmlParser::readAlbum()
             //we use tags instead of genres for creating genres in the database, as the
             //Jamendo.com genres are messy at best
 //             else if ( currentChildElement.tagName() == "tags" )
-//                 tags = currentChildElement.text().split(' ', Qt::SkipEmptyParts);
+//                 tags = currentChildElement.text().split(QLatin1Char(' '), Qt::SkipEmptyParts);
 //             n = n.nextSibling();
         }
     }
@@ -387,7 +387,7 @@ JamendoXmlParser::readTrack()
             break;
         if( m_reader.isStartElement() )
         {
-            QStringRef localname = m_reader.name();
+            QStringView localname = m_reader.name();
             if( localname == "name" )
                 name = m_reader.readElementText();
             else if( localname == "id" )
