@@ -72,7 +72,7 @@ DefaultApplicationController::initEngineController()
 {
     EngineController *controller = new EngineController();
     Components::setEngineController( controller );
-    bool invoked = QMetaObject::invokeMethod( controller, "initializePhonon", Qt::DirectConnection );
+    bool invoked = QMetaObject::invokeMethod( controller, "initializeBackend", Qt::DirectConnection );
     Q_ASSERT( invoked );
     Q_UNUSED( invoked );
 }
