@@ -18,11 +18,14 @@
 #define STATSYNCING_CONTROLLER_H
 
 #include "amarok_export.h"
-// for CollectionManager::CollectionStatus that cannont be fwd-declared
+// for CollectionManager::CollectionStatus that cannot be fwd-declared
 #include "core-impl/collections/support/CollectionManager.h"
 
-#include <QWeakPointer>
+#include <QPointer>
 #include <QDateTime>
+#include <QMap>
+
+#include <KLocalizedString>
 
 class QTimer;
 
@@ -32,11 +35,11 @@ namespace StatSyncing
     class CreateProviderDialog;
     class Process;
     class Provider;
-    typedef QExplicitlySharedDataPointer<Provider> ProviderPtr;
+    typedef QSharedPointer<Provider> ProviderPtr;
     typedef QList<ProviderPtr> ProviderPtrList;
     class ProviderFactory;
     class ScrobblingService;
-    typedef QExplicitlySharedDataPointer<ScrobblingService> ScrobblingServicePtr;
+    typedef QSharedPointer<ScrobblingService> ScrobblingServicePtr;
 
     /**
      * A singleton class that controls statistics synchronization and related tasks.
@@ -46,8 +49,8 @@ namespace StatSyncing
         Q_OBJECT
 
         public:
-            explicit Controller( QObject *parent = 0 );
-            ~Controller();
+            explicit Controller( QObject *parent = nullptr );
+            ~Controller() override;
 
             /**
              * Return a list of Meta::val* fields that statistics synchronization can
@@ -64,7 +67,8 @@ namespace StatSyncing
             virtual void registerProvider( const ProviderPtr &provider );
 
             /**
-             * Forget about StatSyncing::Provider @param provider.
+             * Forget about StatSyncing::Provider @p provider.
+             * @param provider the provider
              */
             virtual void unregisterProvider( const ProviderPtr &provider );
 
@@ -73,10 +77,10 @@ namespace StatSyncing
              * multiple provider instances. This method is called by Amarok's plugin
              * infrastructure.
              */
-            void setFactories( const QList<Plugins::PluginFactory*> &factories );
+            void setFactories( const QList<QSharedPointer<Plugins::PluginFactory> > &factories );
 
             /**
-             * Returns true if any instantiable provider types are registered with the
+             * Returns true if any instantiatable provider types are registered with the
              * controller.
              */
             bool hasProviderFactories() const;
@@ -130,7 +134,7 @@ namespace StatSyncing
              */
             Config *config();
 
-        public slots:
+        public Q_SLOTS:
             /**
              * Start the whole synchronization machinery. This call returns quickly,
              * way before the synchronization is finished.
@@ -152,7 +156,7 @@ namespace StatSyncing
             void scrobble( const Meta::TrackPtr &track, double playedFraction = 1.0,
                            const QDateTime &time = QDateTime() );
 
-        signals:
+        Q_SIGNALS:
             /**
              * Emitted when a track passed to scrobble() is successfully queued for
              * scrobbling submission. This signal is emitted for every scrobbling service.
@@ -161,24 +165,26 @@ namespace StatSyncing
             void trackScrobbled( const ScrobblingServicePtr &service, const Meta::TrackPtr &track );
 
             /**
-             * Emitted when a scrobbling service @service was unable to scrobble() a track.
+             * Emitted when a scrobbling service @p service was unable to scrobble() a track.
              *
+             * @param service the service
+             * @param track the track
              * @param error is a ScrobblingService::ScrobbleError enum value.
              */
             void scrobbleFailed( const ScrobblingServicePtr &service, const Meta::TrackPtr &track, int error );
 
-        private slots:
+        private Q_SLOTS:
             /**
              * Creates new instance of provider type identified by @param type
              * with configuration stored in @param config.
              */
-            void createProvider( QString type, QVariantMap config );
+            void createProvider( const QString &type, const QVariantMap &config );
 
             /**
              * Reconfigures provider identified by @param id with configuration
              * stored in @param config.
              */
-            void reconfigureProvider( QString id, QVariantMap config );
+            void reconfigureProvider( const QString &id, const QVariantMap &config );
 
             /**
              * Can only be connected to provider changed() signal
@@ -194,7 +200,7 @@ namespace StatSyncing
                                       CollectionManager::CollectionStatus status );
             void slotCollectionRemoved( const QString &id );
             void startNonInteractiveSynchronization();
-            void synchronize( int mode );
+            void synchronizeWithMode( int mode );
 
             void slotTrackFinishedPlaying( const Meta::TrackPtr &track, double playedFraction );
             void slotResetLastSubmittedNowPlayingTrack();
@@ -209,11 +215,11 @@ namespace StatSyncing
              * Return true if important metadata of both tracks is equal.
              */
             bool tracksVirtuallyEqual( const Meta::TrackPtr &first, const Meta::TrackPtr &second );
-            QMap<QString, ProviderFactory*> m_providerFactories;
+            QMap<QString, QSharedPointer<ProviderFactory> > m_providerFactories;
 
             // synchronization-related
             ProviderPtrList m_providers;
-            QWeakPointer<Process> m_currentProcess;
+            QPointer<Process> m_currentProcess;
             QTimer *m_startSyncingTimer;
             Config *m_config;
 
@@ -223,7 +229,7 @@ namespace StatSyncing
              * milliseconds to let the collection settle down. Moreover, if the newly
              * added collection emits updated(), the timeout will run from start again.
              *
-             * (reason: e.g. iPod Collectin appears quickly, but with no tracks, which
+             * (reason: e.g. iPod Collection appears quickly, but with no tracks, which
              * are added gradually as they are parsed. This "ensures" we only start
              * syncing as soon as all tracks are parsed.)
              */
