@@ -24,9 +24,10 @@ using namespace StatSyncing;
 SimpleWritableTrack::SimpleWritableTrack( const Meta::FieldHash &metadata,
                                           const QSet<QString> &labels )
     : SimpleTrack( metadata, labels )
+    , m_changes( 0 )
 {
     // Move statistics to separate container, so we don't have to lock for other metadata
-    foreach( const qint64 metaValue, metadata.keys() )
+    for( const qint64 metaValue : metadata.keys() )
     {
         switch( metaValue )
         {
