@@ -161,11 +161,7 @@ void BookmarkPopup::mouseMoveEvent ( QMouseEvent * event )
     }
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void BookmarkPopup::enterEvent ( QEvent * )
-#else
 void BookmarkPopup::enterEvent ( QEnterEvent * )
-#endif
 {
     m_hasMouseOver = true;
 }
