@@ -34,11 +34,7 @@ Q_SIGNALS:
     void toggled(bool playing);
 
 protected:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    void enterEvent( QEvent * ) override;
-#else
     void enterEvent( QEnterEvent * ) override;
-#endif
     void leaveEvent( QEvent * ) override;
     void mousePressEvent( QMouseEvent * ) override;
     void reloadContent( const QSize &sz ) override;
