@@ -37,11 +37,7 @@ Wrench::Wrench( QWidget *parent ) : QLabel( parent )
 }
 
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void Wrench::enterEvent( QEvent* )
-#else
 void Wrench::enterEvent( QEnterEvent* )
-#endif
 {
     setMargin( 1 );
     update();
@@ -116,11 +112,7 @@ TokenWithLayout::~TokenWithLayout()
     delete m_wrench;
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void TokenWithLayout::enterEvent( QEvent* e )
-#else
 void TokenWithLayout::enterEvent( QEnterEvent* e )
-#endif
 {
     QWidget *win = window();
     const int sz = 2*height();
