@@ -67,11 +67,7 @@ void VolumeDial::paletteChanged( const QPalette &palette )
 }
 
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void VolumeDial::enterEvent ( QEvent * )
-#else
 void VolumeDial::enterEvent ( QEnterEvent * )
-#endif
 {
     startFade();
 }
