@@ -22,6 +22,8 @@
 class TestSingleCollectionTreeItemModel : public QObject
 {
     Q_OBJECT
+public:
+    TestSingleCollectionTreeItemModel();
 
 private Q_SLOTS:
     void initTestCase();
