@@ -73,7 +73,7 @@ public:
 class MyAlbumMock : public MockAlbum
 {
 public:
-    MyAlbumMock() : MockAlbum( "testAlbum" ) {}
+    MyAlbumMock() : MockAlbum( QStringLiteral("testAlbum") ) {}
 
     bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override
     {
@@ -97,7 +97,7 @@ public:
 class MyArtistMock : public MockArtist
 {
 public:
-    MyArtistMock() : MockArtist( "testArtist" ) {}
+    MyArtistMock() : MockArtist( QStringLiteral("testArtist") ) {}
 
     bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override
     {
@@ -121,7 +121,7 @@ public:
 class MyGenreMock : public MockGenre
 {
 public:
-    MyGenreMock() : MockGenre( "testGenre" ) {}
+    MyGenreMock() : MockGenre( QStringLiteral("testGenre") ) {}
 
     bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override
     {
@@ -145,7 +145,7 @@ public:
 class MyComposerMock : public MockComposer
 {
 public:
-    MyComposerMock() : MockComposer( "testComposer" ) {}
+    MyComposerMock() : MockComposer( QStringLiteral("testComposer") ) {}
 
     bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override
     {
@@ -169,7 +169,7 @@ public:
 class MyYearMock : public MockYear
 {
 public:
-    MyYearMock() : MockYear( "testYear" ) {}
+    MyYearMock() : MockYear( QStringLiteral("testYear") ) {}
 
     bool hasCapabilityInterface( Capabilities::Capability::Type type ) const override
     {
@@ -219,7 +219,7 @@ TestAggregateMeta::testCreateCapabilityOnSingleTrack()
 {
     MyTrackMock *mock = new MyTrackMock();
     QMap<Capabilities::Capability::Type, Capabilities::Capability*>  capabilities;
-    capabilities.insert( Capabilities::Capability::Buyable, 0 );
+    capabilities.insert( Capabilities::Capability::Buyable, nullptr );
     Capabilities::Capability *cap = new MyOrganiseCapability();
     capabilities.insert( Capabilities::Capability::Organisable, cap );
 
@@ -258,7 +258,7 @@ TestAggregateMeta::testCreateCapabilityOnSingleAlbum()
 {
     MyAlbumMock *mock = new MyAlbumMock();
     QMap<Capabilities::Capability::Type, Capabilities::Capability*>  capabilities;
-    capabilities.insert( Capabilities::Capability::Buyable, 0 );
+    capabilities.insert( Capabilities::Capability::Buyable, nullptr );
     Capabilities::Capability *cap = new MyOrganiseCapability();
     capabilities.insert( Capabilities::Capability::Organisable, cap );
 
@@ -297,7 +297,7 @@ TestAggregateMeta::testCreateCapabilityOnSingleArtist()
 {
     MyArtistMock *mock = new MyArtistMock();
     QMap<Capabilities::Capability::Type, Capabilities::Capability*>  capabilities;
-    capabilities.insert( Capabilities::Capability::Buyable, 0 );
+    capabilities.insert( Capabilities::Capability::Buyable, nullptr );
     Capabilities::Capability *cap = new MyOrganiseCapability();
     capabilities.insert( Capabilities::Capability::Organisable, cap );
 
@@ -336,7 +336,7 @@ TestAggregateMeta::testCreateCapabilityOnSingleComposer()
 {
     MyComposerMock *mock = new MyComposerMock();
     QMap<Capabilities::Capability::Type, Capabilities::Capability*>  capabilities;
-    capabilities.insert( Capabilities::Capability::Buyable, 0 );
+    capabilities.insert( Capabilities::Capability::Buyable, nullptr );
     Capabilities::Capability *cap = new MyOrganiseCapability();
     capabilities.insert( Capabilities::Capability::Organisable, cap );
 
@@ -375,7 +375,7 @@ TestAggregateMeta::testCreateCapabilityOnSingleGenre()
 {
     MyGenreMock *mock = new MyGenreMock();
     QMap<Capabilities::Capability::Type, Capabilities::Capability*>  capabilities;
-    capabilities.insert( Capabilities::Capability::Buyable, 0 );
+    capabilities.insert( Capabilities::Capability::Buyable, nullptr );
     Capabilities::Capability *cap = new MyOrganiseCapability();
     capabilities.insert( Capabilities::Capability::Organisable, cap );
 
@@ -414,7 +414,7 @@ TestAggregateMeta::testCreateCapabilityOnSingleYear()
 {
     MyYearMock *mock = new MyYearMock();
     QMap<Capabilities::Capability::Type, Capabilities::Capability*>  capabilities;
-    capabilities.insert( Capabilities::Capability::Buyable, 0 );
+    capabilities.insert( Capabilities::Capability::Buyable, nullptr );
     Capabilities::Capability *cap = new MyOrganiseCapability();
     capabilities.insert( Capabilities::Capability::Organisable, cap );
 
@@ -503,11 +503,11 @@ void
 TestAggregateMeta::testPrettyUrl()
 {
     Meta::MockTrack *mock = new ::testing::NiceMock<Meta::MockTrack>();
-    EXPECT_CALL( *mock, prettyUrl() ).Times( AnyNumber() ).WillRepeatedly( Return( "foo" ) );
+    EXPECT_CALL( *mock, prettyUrl() ).Times( AnyNumber() ).WillRepeatedly( Return( QStringLiteral("foo") ) );
 
     Meta::TrackPtr trackPtr( mock );
 
     Meta::AggregateTrack track( nullptr, trackPtr );
 
-    QCOMPARE( track.prettyUrl(), QString( "foo" ) );
+    QCOMPARE( track.prettyUrl(), QStringLiteral( "foo" ) );
 }
