@@ -854,6 +854,30 @@ TestSqlQueryMaker::testReturnFunctions()
     QCOMPARE( qm.customData().first(), result );
 }
 
+void
+TestSqlQueryMaker::testEmptyMatch()
+{
+    Collections::SqlQueryMaker qm( m_collection );
+    qm.setBlocking( true );
+    qm.setQueryType( Collections::QueryMaker::Track );
+
+    qm.addFilter( Meta::valComment, QStringLiteral(""), true, true );
+    qm.run();
+    checkResultCount( &qm, Collections::QueryMaker::Track, 2 );
+}
+
+void
+TestSqlQueryMaker::testNotEmptyMatch()
+{
+    Collections::SqlQueryMaker qm( m_collection );
+    qm.setBlocking( true );
+    qm.setQueryType( Collections::QueryMaker::Track );
+
+    qm.excludeFilter( Meta::valComment, QStringLiteral(""), true, true );
+    qm.run();
+    checkResultCount( &qm, Collections::QueryMaker::Track, 4 );
+}
+
 void
 TestSqlQueryMaker::testLabelMatch()
 {
